/* Copyright (C) 2015-2018 McAfee, Inc.  All rights reserved.*/

/*
install.sql is executed when this extension is installed in EPO.
The file is executed sequentially hence tables should created first and then
data should be inserted.
Before creating each table a check must be performed which ensures that the table is not already present.
This is done so as to make the sql reentrant.
Before writing any alter table statement also check for existence/non existence so as to make sql reentrant.
Create tables in the "Create Tables Section" and insert data into "Insert Data Section".
*/


/* Create Tables Section */
/* After Creating a table also register it with SQUID in beans.xml */

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CONFIG]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
    create table  [dbo].[SCOR_CONFIG] (
        ID int IDENTITY(1,1) NOT NULL,
        CONTEXT nvarchar(255),
	    NAME nvarchar(100),
        VALUE nvarchar(MAX),
        DEFAULT_VALUE nvarchar(MAX),
		VALUE_TYPE nvarchar(32) default 'TEXT',
		EDITABLE nchar(1) default 'Y',
		VIEWABLE nchar(1) default 'Y',
        primary key (ID)
    )
    alter table [dbo].[SCOR_CONFIG] add constraint SCOR_CHK_CONFIG_VALUE_TYPE CHECK (VALUE_TYPE in ('TEXT', 'BOOLEAN', 'NUMBER', 'DECIMAL', 'TEXTLIST'));
    alter table [dbo].[SCOR_CONFIG] add constraint SCOR_UNIQUE_CONFIG_CONTEXT_NAME UNIQUE  (NAME);
END
GO


/*#start# upgrade statements from 6.1.0 to 6.1.1*/

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_CONFIG') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_CONFIG', 'DEFAULT_VALUE') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_CONFIG] ADD DEFAULT_VALUE nvarchar(MAX)
END 
GO

/*#end# upgrade statements from 6.1.0 to 6.1.1*/

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_INV_SYSTEM_PROPERTIES]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [SCOR_INV_SYSTEM_PROPERTIES](
      [AGENTGUID] uniqueidentifier NOT NULL,    
      [INVENTORY_FETCH_TIME] datetime NULL,
      [INVENTORY_FETCH_STATUS] tinyint NOT NULL DEFAULT 0,
      [JVM_MEMORY_REQUIRED] tinyint NOT NULL DEFAULT 0,
      [ROLLUP_TIMESTAMP] rowversion NOT NULL,
      primary key (AGENTGUID)
)
     create index SCOR_IDX_SCOR_INV_SYSTEM_PROPERTIES_INVENTORY_FETCH_TIME on [dbo].[SCOR_INV_SYSTEM_PROPERTIES] (INVENTORY_FETCH_TIME);

END
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_INV_SAVED_SEARCHES]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_INV_SAVED_SEARCHES](
  [SEARCH_ID] int IDENTITY(1,1) NOT NULL,
  [SEARCH_NAME] nvarchar(256) NOT NULL,
  [INV_VIEW_TYPE] nvarchar(32) NOT NULL,
  [ADVANCE_FILTER] nvarchar(max) NOT NULL,
  [USER_ID] int NULL,
  [ROLLUP_TIMESTAMP] rowversion NOT NULL,
  primary key (SEARCH_ID)
 )
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_INV_APPS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_INV_APPS](
  [APP_ID] int IDENTITY(1,1) NOT NULL,
  [APP_NAME] nvarchar(256) NOT NULL,
  [APP_VERSION] nvarchar(64) NULL,
  [APP_VENDOR] nvarchar(256) NULL,
  [APP_DISP_NAME] nvarchar(256) NOT NULL,
  [APP_DISP_VERSION] nvarchar(64) NULL,
  [APP_DISP_VENDOR] nvarchar(256) NULL,
  [CUSTOM_TRUST_LEVEL] tinyint NOT NULL DEFAULT 1,
  [HIDDEN] bit NOT NULL DEFAULT 0,
  [IS_REPUTATION_SYNCED] bit NOT NULL DEFAULT 0,
  [ROLLUP_TIMESTAMP] rowversion NOT NULL,
  [APP_VERSION_CPE] nvarchar(256) NULL,
  primary key (APP_ID)
 )
     create index SCOR_INV_APPS_APP_NAME on [dbo].[SCOR_INV_APPS] (APP_NAME);
     create index SCOR_INV_APPS_APP_DISP_NAME on [dbo].[SCOR_INV_APPS] (APP_DISP_NAME);
     create index SCOR_INV_APPS_APP_DISP_VENDOR on [dbo].[SCOR_INV_APPS] (APP_DISP_VENDOR);
END
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_INV_BINARIES]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_INV_BINARIES](
	[BINARY_ID] int IDENTITY(1,1) NOT NULL,
	[BINARY_EMBED_NAME] nvarchar(256) NULL,
	[BINARY_EMBED_VERSION] nvarchar(64) NULL,
	[BINARY_EMBED_APP_NAME] nvarchar(256) NULL,
    [BINARY_EMBED_APP_VERSION] nvarchar(64) NULL,
    [BINARY_EMBED_APP_VENDOR] nvarchar(256) NULL,
	[BINARY_BASE_NAME] nvarchar(256) NOT NULL,
	[BINARY_SHA1] varchar(40)  NOT NULL,
	[BINARY_SHA256] nvarchar(64)  NULL,
	[BINARY_MD5] varchar(32) NULL,
	[BINARY_SIZE] bigint  NOT NULL,
	[BINARY_TYPE] nvarchar(64) NOT NULL,
    [IS_INSTALLER] bit NOT NULL,
    [HAS_CERTS] bit NOT NULL,
	[FIRST_SEEN_TIME] datetime NULL,
	[FIRST_SEEN_HOST] nvarchar(256) NULL,
	[APP_ID] int NULL,
	[ROLLUP_TIMESTAMP] rowversion NOT NULL,
	[HIDDEN] bit NOT NULL DEFAULT 0,
	[BINARY_REPUTATION_ID] int NULL,
	primary key (BINARY_ID)
    )ALTER TABLE SCOR_INV_BINARIES ADD FOREIGN KEY (APP_ID)  REFERENCES SCOR_INV_APPS(APP_ID);
    
     create index SCOR_INV_BINARIES_BINARY_BASE_NAME on [dbo].[SCOR_INV_BINARIES] (BINARY_BASE_NAME);
     create index SCOR_IDX_INV_BINARIES_BINARY_SHA1_INCLUDE_BASE_NAME_APP_ID on [dbo].[SCOR_INV_BINARIES] (BINARY_SHA1) INCLUDE (BINARY_BASE_NAME, APP_ID);
     create index SCOR_IDX_INV_BINARIES_APP_ID on [dbo].[SCOR_INV_BINARIES] (APP_ID) ;
     create index SCOR_IDX_INV_BINARIES_REPUTATION_ID on [dbo].[SCOR_INV_BINARIES] (BINARY_REPUTATION_ID);
     /* TODO: Handle migration for BINARY_MD5 index */
     create index SCOR_INV_BINARIES_BINARY_MD5 on [dbo].[SCOR_INV_BINARIES] (BINARY_MD5);
END
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_BINARY_PATHS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_BINARY_PATHS](
	[ID] [int] IDENTITY(1,1) NOT NULL,
	[BINARY_PATH] nvarchar(4000) NOT NULL,
	[BINARY_PATH_HASH] int NOT NULL,
	primary key (ID)
	)
     CREATE NONCLUSTERED INDEX [SCOR_BINARY_PATHS_BINARY_PATH_HASH]
	 ON [dbo].[SCOR_BINARY_PATHS] ([BINARY_PATH_HASH]);
END
GO

/*
 * While updating the table, please update the corresponding view SCOR_VW_HOST_BINARY_ASSOC_WITH_PATH too.
 * */

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_HOST_BINARY_ASSOC]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_HOST_BINARY_ASSOC](
	[ID] [bigint] IDENTITY(1,1) NOT NULL,
	[EXECUTION_STATUS] bit  NOT NULL,
	[FETCH_TIME] smalldatetime DEFAULT getutcdate() NOT NULL,
	[INV_TIME] datetime,
	[BINARY_ADDITION_TIME] datetime,
	[IS_ALLOWED_BY_CHECKSUM] tinyint  NOT NULL,
	[IS_ALLOWED_BY_CERT] bit NOT NULL,
	[IS_ALLOWED_BY_NAME] tinyint NOT NULL,
	[IS_ALLOWED_BY_TRUSTED_PATH] bit NOT NULL,
	[IS_SOLIDIFIED] tinyint NOT NULL,
	[IS_UPDATER] bit NOT NULL,
	[IS_SYSTEM_FILE] bit NOT NULL,
	[BINARY_ID] int NOT NULL,
	[AGENTGUID] uniqueidentifier NOT NULL,
	[ROLLUP_TIMESTAMP] rowversion NOT NULL,
	[BINARY_PATH_ID] int NOT NULL,
	primary key (ID)
	)
	ALTER TABLE [dbo].[SCOR_HOST_BINARY_ASSOC] ADD constraint SCOR_ASSOC_SYSTEM_PROPERTIES
    	FOREIGN KEY (AGENTGUID) REFERENCES [dbo].[SCOR_INV_SYSTEM_PROPERTIES] ON DELETE CASCADE ON UPDATE CASCADE;
    
     CREATE NONCLUSTERED INDEX [SCOR_IDX_SCOR_HOST_BINARY_ASSOC_AGENTGUID_INCLUDE_BINARY_ID]
	 ON [dbo].[SCOR_HOST_BINARY_ASSOC] ([AGENTGUID])
     INCLUDE ([BINARY_ID]);

	CREATE NONCLUSTERED INDEX [SCOR_HOST_BINARY_ASSOC_INV_FEEDBACK_COLUMNS_INCLUDE_AGENTGUID] ON [dbo].[SCOR_HOST_BINARY_ASSOC] 
	([BINARY_ID] ASC) 
	INCLUDE ([AGENTGUID], [IS_SYSTEM_FILE], [IS_UPDATER], [EXECUTION_STATUS], [IS_ALLOWED_BY_CHECKSUM], 
	[IS_ALLOWED_BY_CERT], [IS_SOLIDIFIED], [BINARY_ADDITION_TIME]); 
	
     CREATE NONCLUSTERED INDEX [SCOR_HOST_BINARY_ASSOC_BINARY_PATH_ID] ON [dbo].[SCOR_HOST_BINARY_ASSOC] ([BINARY_PATH_ID]);
     CREATE NONCLUSTERED INDEX [SCOR_HOST_BINARY_ASSOC_FETCH_TIME] ON [dbo].[SCOR_HOST_BINARY_ASSOC] ([FETCH_TIME]) INCLUDE ([AGENTGUID]);
     CREATE NONCLUSTERED INDEX [SCOR_IDX_SCOR_HOST_BINARY_ASSOC_BINARY_ID] ON [dbo].[SCOR_HOST_BINARY_ASSOC] ([BINARY_ID]);
END
GO

if (dbo.SCOR_CHECK_TABLE_EXISTS('SCOR_STAGING_HOST_BINARY_ASSOC_MAPPING' ) = 0) 
BEGIN	
CREATE TABLE [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC_MAPPING]( 
				ID int IDENTITY(1,1) NOT NULL,
				[AGENTGUID] [uniqueidentifier] NOT NULL,
				[PARTITION_ID] [int],
				[ROLLUP_TIMESTAMP] [timestamp] NOT NULL,
				[LAST_UPDATE_TIME] [datetime], 
				[LAST_SYNC_TIME] [datetime], 
				[LAST_FETCH_TIME] [datetime],
				primary key (ID))
	create index SCOR_IDX_STAGING_HOST_BINARY_ASSOC_MAPPING_AGENTGUID on [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC_MAPPING] (AGENTGUID);
END
GO

DECLARE @isPartitionedStagingHostTableCreated bit;
SET @isPartitionedStagingHostTableCreated = 0;
BEGIN TRY
	if (dbo.SCOR_FN_IS_PARTITIONING_SUPPORTED() = 1)
	BEGIN
		/* Create integer partition function for 100 partitions based on partition id, one partition for each partition id in the range 1-100 */
		if not exists (select 1 from sys.partition_functions where name = 'SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_FN')
		BEGIN
			DECLARE @StagingHostAssocPartitionFunction nvarchar(max);
			SET @StagingHostAssocPartitionFunction = N'CREATE PARTITION FUNCTION [SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_FN](int) AS RANGE RIGHT FOR VALUES (';
			DECLARE @i int;
			SET @i = 1;
			WHILE @i < 99
			BEGIN
			SET @StagingHostAssocPartitionFunction = @StagingHostAssocPartitionFunction + CAST(@i as nvarchar(10)) + N', ';
			SET @i = @i + 1;
			END
			SET @StagingHostAssocPartitionFunction = @StagingHostAssocPartitionFunction + CAST(@i as nvarchar(10)) + N');';
			EXEC sp_executesql @StagingHostAssocPartitionFunction;
		END
		
		if not exists (select 1 from sys.partition_schemes where name = 'SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_SCHEME')
		BEGIN
			CREATE PARTITION SCHEME [SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_SCHEME]
			AS PARTITION [SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_FN] ALL TO ([PRIMARY]);
		END
		
		/*Create Table on partition scheme*/
		
		if (dbo.SCOR_CHECK_TABLE_EXISTS('SCOR_STAGING_HOST_BINARY_ASSOC' ) = 0) 
		BEGIN
			CREATE TABLE [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC](
				[ID] [bigint] IDENTITY(1,1) NOT NULL,
				[EXECUTION_STATUS] bit  NOT NULL,
				[FETCH_TIME] smalldatetime DEFAULT getutcdate() NOT NULL,
				[INV_TIME] datetime,
				[BINARY_ADDITION_TIME] datetime,
				[IS_ALLOWED_BY_CHECKSUM] tinyint  NOT NULL,
				[IS_ALLOWED_BY_CERT] bit NOT NULL,
				[IS_ALLOWED_BY_NAME] tinyint NOT NULL,
				[IS_ALLOWED_BY_TRUSTED_PATH] bit NOT NULL,
				[IS_SOLIDIFIED] tinyint NOT NULL,
				[IS_UPDATER] bit NOT NULL,
				[IS_SYSTEM_FILE] bit NOT NULL,
				[BINARY_ID] int NOT NULL,
				[AGENTGUID] uniqueidentifier NOT NULL,
				[ROLLUP_TIMESTAMP] rowversion NOT NULL,
				[BINARY_PATH_ID] int NOT NULL,
				[PARTITION_ID] int NOT NULL
			) ON [SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_SCHEME](PARTITION_ID)
		    
			CREATE CLUSTERED INDEX [SCOR_STAGING_HOST_ASSOC_PARTN_IDX_PARTITON_ID]
			ON [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC] (PARTITION_ID)
			ON [SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_SCHEME](PARTITION_ID)
			
			ALTER TABLE [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC] ADD constraint SCOR_PK_STAGING_HOST_ASSOC_PARTITION_ID
			PRIMARY KEY NONCLUSTERED (ID ASC, PARTITION_ID ASC)
			ON [SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_SCHEME](PARTITION_ID)
			
			CREATE NONCLUSTERED INDEX [SCOR_STAGING_HOST_ASSOC_IDX_AGENTGUID]
			ON [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC] (AGENTGUID ASC)
			ON [SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_SCHEME](PARTITION_ID)
		
			CREATE NONCLUSTERED INDEX [SCOR_STAGING_HOST_ASSOC_IDX_ID_BINARY_ID_PATH_ID]
			ON [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC] (ID ASC) INCLUDE (BINARY_ID, BINARY_PATH_ID)
			ON [SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_SCHEME](PARTITION_ID)

			insert into SCOR_CONFIG(CONTEXT, NAME, VALUE, DEFAULT_VALUE, VALUE_TYPE, EDITABLE, VIEWABLE) VALUES ('inventory', 'isStagingHostAssocPartitioned', 'true', 'false', 'BOOLEAN', 'N', 'N');
			
			set @isPartitionedStagingHostTableCreated = 1;
			
		END	-- End table creation
	END		-- End partition function, scheme and table creation
END TRY

BEGIN CATCH
	set @isPartitionedStagingHostTableCreated = 0;
END CATCH

if (@isPartitionedStagingHostTableCreated = 0)
BEGIN
	if (dbo.SCOR_CHECK_TABLE_EXISTS('SCOR_STAGING_HOST_BINARY_ASSOC' ) = 0) 
	BEGIN
		CREATE TABLE [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC](
			[ID] [bigint] IDENTITY(1,1) NOT NULL,
			[EXECUTION_STATUS] bit  NOT NULL,
			[FETCH_TIME] smalldatetime DEFAULT getutcdate() NOT NULL,
			[INV_TIME] datetime,
			[BINARY_ADDITION_TIME] datetime,
			[IS_ALLOWED_BY_CHECKSUM] tinyint  NOT NULL,
			[IS_ALLOWED_BY_CERT] bit NOT NULL,
			[IS_ALLOWED_BY_NAME] tinyint NOT NULL,
			[IS_ALLOWED_BY_TRUSTED_PATH] bit NOT NULL,
			[IS_SOLIDIFIED] tinyint NOT NULL,
			[IS_UPDATER] bit NOT NULL,
			[IS_SYSTEM_FILE] bit NOT NULL,
			[BINARY_ID] int NOT NULL,
			[AGENTGUID] uniqueidentifier NOT NULL,
			[ROLLUP_TIMESTAMP] rowversion NOT NULL,
			[BINARY_PATH_ID] int NOT NULL,
			[PARTITION_ID] int NOT NULL,
			primary key (id)
		);
		
		CREATE NONCLUSTERED INDEX [SCOR_STAGING_HOST_ASSOC_IDX_AGENTGUID]
		ON [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC] (AGENTGUID ASC);

		CREATE NONCLUSTERED INDEX [SCOR_STAGING_HOST_ASSOC_IDX_ID_BINARY_ID_PATH_ID]
			ON [dbo].[SCOR_STAGING_HOST_BINARY_ASSOC] (ID ASC) INCLUDE (BINARY_ID, BINARY_PATH_ID)
		
		insert into SCOR_CONFIG(CONTEXT, NAME, VALUE, DEFAULT_VALUE, VALUE_TYPE, EDITABLE, VIEWABLE) VALUES ('inventory', 'isStagingHostAssocPartitioned', 'false', 'false', 'BOOLEAN', 'N', 'N');
					
	END		-- End table creation
END 		-- End if
GO

if (dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_NORM_VENDORS') = 0)
BEGIN
CREATE TABLE [dbo].[SCOR_NORM_VENDORS](
  [ID] int IDENTITY(1,1) NOT NULL,
  [NAME] nvarchar(1024) NOT NULL,
  primary key (ID)
 )
END
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_ALERTS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
    CREATE TABLE [dbo].[SCOR_ALERTS](
	[ALERT_ID] [int] IDENTITY(1,1) NOT NULL,
	[ALERT_TIMESTAMP] [datetime] NOT NULL  DEFAULT (getutcdate()),
	[DISMISSED] [numeric](1, 0) NULL,
	[SEVERITY] [numeric](1, 0) NULL,
	[ALERT_MESSAGE] [nvarchar](max) NULL,
 	primary key (ALERT_ID)
        )
    create index SCOR_ALERTS_TIMESTAMP on [dbo].[SCOR_ALERTS] (ALERT_TIMESTAMP);
END
GO
if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_EVENTS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN

    --If EPOEvents table has BIGINT column then create ParentID column as BIGINT
    IF	EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'BIGINT' AND TABLE_NAME = 'EPOEventsMT' AND COLUMN_NAME = 'AutoID')
    BEGIN
	
	    create table [dbo].[SCOR_EVENTS] (
	        AutoID BIGINT IDENTITY(1,1) NOT NULL,
		AutoGUID uniqueidentifier NOT NULL CONSTRAINT [DF_SCOR_EVENTS_EventID]  DEFAULT (newid()),
		EPO_EVENT_AUTO_ID BIGINT,
	        EVT_ATTR_NAME nvarchar(1024),
	        EVT_COMMENT nvarchar(4000),
	        EVT_ERROR nvarchar(128),
	        EVT_DISPLAY_KEY nvarchar(256),
	        EVT_NAME nvarchar(100) not NULL,
	        EVT_CMD_LINE nvarchar(4000),
	        EVT_CMD_USER_NAME nvarchar(512),
	        EVT_CMD_STATUS nvarchar(128),
	        EVT_SEQ_NO numeric(19,0),
	        EVT_FILE_NAME nvarchar(1024),
	        HOST_NAME nvarchar(256),
		AGENTGUID uniqueidentifier,
	        EVT_LOGON_HOST_NAME nvarchar(256),
	        EVT_LOGON_PROCESS nvarchar(1024),
	        EVT_LOGON_REMOTE_HOST_NAME nvarchar(256),
	        EVT_NEW_FILE_NAME nvarchar(1024),
	        EVT_OBJECT nvarchar(1024),
	        EVT_VALUE1 nvarchar(1024),
	        EVT_ORIG_USER_NAME nvarchar(256),
	        EVT_PROCESS_ID nvarchar(1024),
		EVT_PROG_NAME nvarchar(1024),
	        EVT_REG_KEY_NAME nvarchar(1024),
	        EVT_REG_VALUE_DATA nvarchar(1024),
	        EVT_REG_VALUE_NAME nvarchar(1024),
	        EVT_REG_VALUE_TYPE nvarchar(64),
		EVT_MODIFICATION_TYPE nvarchar(64),
	        DETECTEDUTC datetime NOT NULL,
	        RECEIVEDUTC datetime NOT NULL CONSTRAINT [DF_SCOR_EVENTS_ReceivedUTC]  DEFAULT (getutcdate()),
	        EVT_USER_NAME nvarchar(256),
	        EVT_USER_ACCOUNT_NAME nvarchar(256),
	        EVT_WORKFLOW_ID nvarchar(1024),
		EVT_PAR_PROC_NAME nvarchar(1024),
	        EVT_PAR_PROCESS_ID nvarchar(256),
		EVT_PROCESS_SYS_CALL_NUMBER nvarchar(128),
		EVT_PROCESS_RETURN_ADDRESS nvarchar(128),
		EVT_PROCESS_API_NAME nvarchar(1024),
		EVT_VOLUME_NAME nvarchar(1024),
		EVT_FAULTING_ADDR nvarchar(1024),
		THREATEVENTID int not null,
		THREATSEVERITY tinyint,
		RECON_FLAG numeric(8,0) DEFAULT 0,
		RECON_TIX nvarchar(256),
		IS_UPDATER nchar(1) default 'N',
		IS_WINDOW nchar(1) default 'N',
		EVT_FILE_SHA1 varchar(40),
		EVT_FILE_SHA256 varchar(64),
		EVT_FILE_MD5 varchar(32),
		EVT_FILE_TYPE varchar(30),
		EVT_PROCESS_SHA1 varchar(40),
		EVT_PROCESS_SHA256 varchar(64),
		EVT_PROCESS_MD5 varchar(32),
		EVT_DENY_REASON_ID int null,
		EVT_DENY_REASON nvarchar(4000),
		EVT_REPUTATION_SCORE int null,
		ROLLUP_TIMESTAMP [rowversion] NOT NULL,
		USER_COMMENT nvarchar(4000) NULL,
		primary key (AutoID)
	    )
	
	    alter table [dbo].[SCOR_EVENTS] add constraint SCOR_EVENTS_EPO_EVENTS
	    foreign key (EPO_EVENT_AUTO_ID) references  [dbo].[EPOEventsMT] ON DELETE CASCADE ON UPDATE CASCADE;

	END
	ELSE
	BEGIN
		create table [dbo].[SCOR_EVENTS] (
	        AutoID int IDENTITY(1,1) NOT NULL,
		AutoGUID uniqueidentifier NOT NULL CONSTRAINT [DF_SCOR_EVENTS_EventID]  DEFAULT (newid()),
		EPO_EVENT_AUTO_ID int,
	        EVT_ATTR_NAME nvarchar(1024),
	        EVT_COMMENT nvarchar(4000),
	        EVT_ERROR nvarchar(128),
	        EVT_DISPLAY_KEY nvarchar(256),
	        EVT_NAME nvarchar(100) not NULL,
	        EVT_CMD_LINE nvarchar(4000),
	        EVT_CMD_USER_NAME nvarchar(512),
	        EVT_CMD_STATUS nvarchar(128),
	        EVT_SEQ_NO numeric(19,0),
	        EVT_FILE_NAME nvarchar(1024),
	        HOST_NAME nvarchar(256),
		AGENTGUID uniqueidentifier,
	        EVT_LOGON_HOST_NAME nvarchar(256),
	        EVT_LOGON_PROCESS nvarchar(1024),
	        EVT_LOGON_REMOTE_HOST_NAME nvarchar(256),
	        EVT_NEW_FILE_NAME nvarchar(1024),
	        EVT_OBJECT nvarchar(1024),
	        EVT_VALUE1 nvarchar(1024),
	        EVT_ORIG_USER_NAME nvarchar(256),
	        EVT_PROCESS_ID nvarchar(1024),
		EVT_PROG_NAME nvarchar(1024),
	        EVT_REG_KEY_NAME nvarchar(1024),
	        EVT_REG_VALUE_DATA nvarchar(1024),
	        EVT_REG_VALUE_NAME nvarchar(1024),
	        EVT_REG_VALUE_TYPE nvarchar(64),
		EVT_MODIFICATION_TYPE nvarchar(64),
	        DETECTEDUTC datetime NOT NULL,
	        RECEIVEDUTC datetime NOT NULL CONSTRAINT [DF_SCOR_EVENTS_ReceivedUTC]  DEFAULT (getutcdate()),
	        EVT_USER_NAME nvarchar(256),
	        EVT_USER_ACCOUNT_NAME nvarchar(256),
	        EVT_WORKFLOW_ID nvarchar(1024),
		EVT_PAR_PROC_NAME nvarchar(1024),
	        EVT_PAR_PROCESS_ID nvarchar(256),
		EVT_PROCESS_SYS_CALL_NUMBER nvarchar(128),
		EVT_PROCESS_RETURN_ADDRESS nvarchar(128),
		EVT_PROCESS_API_NAME nvarchar(1024),
		EVT_VOLUME_NAME nvarchar(1024),
		EVT_FAULTING_ADDR nvarchar(1024),
		THREATEVENTID int not null,
		THREATSEVERITY tinyint,
		RECON_FLAG numeric(8,0) DEFAULT 0,
		RECON_TIX nvarchar(256),
		IS_UPDATER nchar(1) default 'N',
		IS_WINDOW nchar(1) default 'N',
		EVT_FILE_SHA1 varchar(40),
		EVT_FILE_SHA256 varchar(64),
		EVT_FILE_MD5 varchar(32),
		EVT_FILE_TYPE varchar(30),
		EVT_PROCESS_SHA1 varchar(40),
		EVT_PROCESS_SHA256 varchar(64),
		EVT_PROCESS_MD5 varchar(32),
		EVT_DENY_REASON_ID int null,
		EVT_DENY_REASON nvarchar(4000),
		EVT_REPUTATION_SCORE int null,
		ROLLUP_TIMESTAMP [rowversion] NOT NULL,
		USER_COMMENT nvarchar(4000) NULL,
		primary key (AutoID)
	    )

	    alter table [dbo].[SCOR_EVENTS] add constraint SCOR_EVENTS_EPO_EVENTS
	    foreign key (EPO_EVENT_AUTO_ID) references  [dbo].[EPOEvents] ON DELETE CASCADE ON UPDATE CASCADE;

	END

	    create index SCOR_EVENTS_EVT_DISPLAY_KEY on [dbo].[SCOR_EVENTS] (EVT_DISPLAY_KEY);
	    create index SCOR_EVENTS_EVT_NAME on [dbo].[SCOR_EVENTS] (EVT_NAME);
	    create index SCOR_EVENTS_HOST_NAME on [dbo].[SCOR_EVENTS] (HOST_NAME);
	    create index SCOR_EVENTS_AGENTGUID on [dbo].[SCOR_EVENTS] (AGENTGUID);
	    create index SCOR_EVENTS_EVT_OBJECT on [dbo].[SCOR_EVENTS] (EVT_OBJECT);
	    create index SCOR_EVENTS_EVT_PROG_NAME on [dbo].[SCOR_EVENTS] (EVT_PROG_NAME);
	    create index SCOR_EVENTS_EVT_USER_NAME on [dbo].[SCOR_EVENTS] (EVT_USER_NAME);
	    create index SCOR_EVENTS_RECON_TIX on [dbo].[SCOR_EVENTS] (RECON_TIX);
	    create index SCOR_EVENTS_RECON_FLAG on [dbo].[SCOR_EVENTS] (RECON_FLAG);
	    create index SCOR_EVENTS_EVT_FILE_NAME on [dbo].[SCOR_EVENTS] (EVT_FILE_NAME);
	    create index SCOR_EVENTS_ORIG_USER_NAME on [dbo].[SCOR_EVENTS] (EVT_ORIG_USER_NAME);
	    create index SCOR_EVENTS_EPO_EVENT_AUTO_ID on [dbo].[SCOR_EVENTS] (EPO_EVENT_AUTO_ID);
	    create index SCOR_EVENTS_DETECTEDUTC_AND_EVTNAME_AGENTGUID on dbo.SCOR_EVENTS (DETECTEDUTC DESC, EVT_NAME, AGENTGUID);

END
GO
-- Scor events rollup table
if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_ROLLUP_EVENTS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
    --If scor_events table has BIGINT column then create ParentID and id columns as BIGINT
    IF	EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'BIGINT' AND TABLE_NAME = 'SCOR_EVENTS' AND COLUMN_NAME = 'AutoID')
    BEGIN
	CREATE TABLE [dbo].[SCOR_ROLLUP_EVENTS] (
    		[Rollup_EventId] [BIGINT] IDENTITY (1, 1) NOT NULL ,
  			[RegSvrId] [int] NOT NULL ,
  			[AutoID] [BIGINT] NOT NULL ,
			AutoGUID uniqueidentifier,
			EPO_EVENT_AUTO_ID BIGINT,
        	EVT_ATTR_NAME nvarchar(1024),
        	EVT_COMMENT nvarchar(4000),
        	EVT_ERROR nvarchar(128),
        	EVT_DISPLAY_KEY nvarchar(256),
        	EVT_NAME nvarchar(100) not NULL,
        	EVT_CMD_LINE nvarchar(4000),
        	EVT_CMD_USER_NAME nvarchar(512),
        	EVT_CMD_STATUS nvarchar(128),
        	EVT_SEQ_NO numeric(19,0),
        	EVT_FILE_NAME nvarchar(1024),
        	HOST_NAME nvarchar(256),
			AGENTGUID uniqueidentifier,
        	EVT_LOGON_HOST_NAME nvarchar(256),
        	EVT_LOGON_PROCESS nvarchar(1024),
        	EVT_LOGON_REMOTE_HOST_NAME nvarchar(256),
        	EVT_NEW_FILE_NAME nvarchar(1024),
        	EVT_OBJECT nvarchar(1024),
        	EVT_VALUE1 nvarchar(1024),
        	EVT_ORIG_USER_NAME nvarchar(256),
        	EVT_PROCESS_ID nvarchar(1024),
			EVT_PROG_NAME nvarchar(1024),
        	EVT_REG_KEY_NAME nvarchar(1024),
        	EVT_REG_VALUE_DATA nvarchar(1024),
        	EVT_REG_VALUE_NAME nvarchar(1024),
        	EVT_REG_VALUE_TYPE nvarchar(64),
			EVT_MODIFICATION_TYPE nvarchar(64),
        	DETECTEDUTC datetime NOT NULL,
       		RECEIVEDUTC datetime NOT NULL,
        	EVT_USER_NAME nvarchar(256),
        	EVT_USER_ACCOUNT_NAME nvarchar(256),
        	EVT_WORKFLOW_ID nvarchar(1024),
			EVT_PAR_PROC_NAME nvarchar(1024),
        	EVT_PAR_PROCESS_ID nvarchar(256),
			EVT_PROCESS_SYS_CALL_NUMBER nvarchar(128),
			EVT_PROCESS_RETURN_ADDRESS nvarchar(128),
			EVT_PROCESS_API_NAME nvarchar(1024),
			EVT_VOLUME_NAME nvarchar(1024),
			EVT_FAULTING_ADDR nvarchar(1024),
			THREATEVENTID int not null,
			THREATSEVERITY tinyint,
			RECON_FLAG numeric(8,0) DEFAULT 0,
			RECON_TIX nvarchar(256),
			IS_UPDATER nchar(1) default 'N',
			IS_WINDOW nchar(1) default 'N',
			EVT_FILE_SHA1 varchar(40),
			EVT_FILE_SHA256 varchar(64),
			EVT_FILE_MD5 varchar(32),
			EVT_FILE_TYPE varchar(30),
			EVT_PROCESS_SHA1 varchar(40),
			EVT_PROCESS_SHA256 varchar(64),
			EVT_PROCESS_MD5 varchar(32),
			EVT_DENY_REASON_ID int null,
			EVT_DENY_REASON nvarchar(4000),
			EVT_REPUTATION_SCORE int null,			
  		CONSTRAINT [PK_SCOR_ROLLUP_EVENTS] PRIMARY KEY CLUSTERED
  		(
    			[RegSvrId],
    			[AutoID]
  		) ON [PRIMARY]
	) ON [PRIMARY]
	END
	ELSE
	BEGIN
	CREATE TABLE [dbo].[SCOR_ROLLUP_EVENTS] (
    		[Rollup_EventId] [int] IDENTITY (1, 1) NOT NULL ,
  			[RegSvrId] [int] NOT NULL ,
  			[AutoID] [int] NOT NULL ,
			AutoGUID uniqueidentifier,
			EPO_EVENT_AUTO_ID int,
        	EVT_ATTR_NAME nvarchar(1024),
        	EVT_COMMENT nvarchar(4000),
        	EVT_ERROR nvarchar(128),
        	EVT_DISPLAY_KEY nvarchar(256),
        	EVT_NAME nvarchar(100) not NULL,
        	EVT_CMD_LINE nvarchar(4000),
        	EVT_CMD_USER_NAME nvarchar(512),
        	EVT_CMD_STATUS nvarchar(128),
        	EVT_SEQ_NO numeric(19,0),
        	EVT_FILE_NAME nvarchar(1024),
        	HOST_NAME nvarchar(256),
			AGENTGUID uniqueidentifier,
        	EVT_LOGON_HOST_NAME nvarchar(256),
        	EVT_LOGON_PROCESS nvarchar(1024),
        	EVT_LOGON_REMOTE_HOST_NAME nvarchar(256),
        	EVT_NEW_FILE_NAME nvarchar(1024),
        	EVT_OBJECT nvarchar(1024),
        	EVT_VALUE1 nvarchar(1024),
        	EVT_ORIG_USER_NAME nvarchar(256),
        	EVT_PROCESS_ID nvarchar(1024),
			EVT_PROG_NAME nvarchar(1024),
        	EVT_REG_KEY_NAME nvarchar(1024),
        	EVT_REG_VALUE_DATA nvarchar(1024),
        	EVT_REG_VALUE_NAME nvarchar(1024),
        	EVT_REG_VALUE_TYPE nvarchar(64),
			EVT_MODIFICATION_TYPE nvarchar(64),
        	DETECTEDUTC datetime NOT NULL,
       		RECEIVEDUTC datetime NOT NULL,
        	EVT_USER_NAME nvarchar(256),
        	EVT_USER_ACCOUNT_NAME nvarchar(256),
        	EVT_WORKFLOW_ID nvarchar(1024),
			EVT_PAR_PROC_NAME nvarchar(1024),
        	EVT_PAR_PROCESS_ID nvarchar(256),
			EVT_PROCESS_SYS_CALL_NUMBER nvarchar(128),
			EVT_PROCESS_RETURN_ADDRESS nvarchar(128),
			EVT_PROCESS_API_NAME nvarchar(1024),
			EVT_VOLUME_NAME nvarchar(1024),
			EVT_FAULTING_ADDR nvarchar(1024),
			THREATEVENTID int not null,
			THREATSEVERITY tinyint,
			RECON_FLAG numeric(8,0) DEFAULT 0,
			RECON_TIX nvarchar(256),
			IS_UPDATER nchar(1) default 'N',
			IS_WINDOW nchar(1) default 'N',
			EVT_FILE_SHA1 varchar(40),
			EVT_FILE_SHA256 varchar(64),
			EVT_FILE_MD5 varchar(32),
			EVT_FILE_TYPE varchar(30),
			EVT_PROCESS_SHA1 varchar(40),
			EVT_PROCESS_SHA256 varchar(64),
			EVT_PROCESS_MD5 varchar(32),
			EVT_DENY_REASON_ID int null,
			EVT_DENY_REASON nvarchar(4000),
			EVT_REPUTATION_SCORE int null,			
  		CONSTRAINT [PK_SCOR_ROLLUP_EVENTS] PRIMARY KEY CLUSTERED
  		(
    			[RegSvrId],
    			[AutoID]
  		) ON [PRIMARY]
	) ON [PRIMARY]
	END
END
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_EVENT_INFO]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
 create table [dbo].[SCOR_EVENT_INFO] (
         ID int IDENTITY(1,1) NOT NULL,
         EVENT_DISPLAY_KEY nvarchar(255),
         ENABLED nchar(1) default 'Y',
         SEARCHABLE nchar(1) default 'Y',
         IS_EPO_EVENT nchar(1) default 'N',
         THREAT_CATEGORY nvarchar(255),
         THREAT_NAME nvarchar(255),
         THREAT_TYPE nvarchar(255),
         THREAT_ACTION_TAKEN nvarchar(255),
         EVENT_TYPE nvarchar(255) NOT NULL,
         IS_SCOR_EVENT nchar(1) default 'Y',
         IS_RECON_REQUIRED nchar(1) default 'Y',
	 	 THREAT_HANDLED bit default NULL,
 	     FD_SUPPORT TINYINT NOT NULL default 0,

	 primary key (ID)
    )
 create index SCOR_SCOR_EVENT_INFO_EVENT_TYPE on [dbo].[SCOR_EVENT_INFO] (EVENT_TYPE);
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_EVENT_DATA_FIELD_MAPPING]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
    create table  [dbo].[SCOR_EVENT_DATA_FIELD_MAPPING] (
        ID int IDENTITY(1,1) NOT NULL,
        SOURCE_FIELD nvarchar(255),
        TABLE_FIELD nvarchar(255),
        TRIM_VALUE numeric(19,0),
        FOR_EPO_EVENT nchar(1) default 'N',
        EVENT_INFO_ID int not null,
        FOR_SCOR_EVENT nchar(1) default 'Y',
        TABLE_FIELD_TYPE nvarchar(5) default '202',
        primary key (ID)
    )

    alter table [dbo].[SCOR_EVENT_DATA_FIELD_MAPPING] add constraint SCOR_EVENT_DATA_FIELD_MAPPING_EVENT_INFO
    foreign key (EVENT_INFO_ID) references  [dbo].[SCOR_EVENT_INFO]
    create index SCOR_EVENT_DATA_FIELD_MAPPING_EVENT_INFO_ID on [dbo].[SCOR_EVENT_DATA_FIELD_MAPPING] (EVENT_INFO_ID);
 
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_RECON_TICKET2]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	create table [dbo].[SCOR_RECON_TICKET2] (
		ID int identity not null,
		TICKET_ID nvarchar(64) not null,
		STAGING_TICKET nvarchar(64) null,
		SUMMARY nvarchar(4000) null,
		UNLOCKED nchar(1) null,
		OLDEST_EVENT datetime null,
		LATEST_EVENT datetime null,
		ROLLUP_TIMESTAMP [rowversion] NOT NULL,		
		primary key (ID)
	)
GO




if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DIAG]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
    create table [dbo].[SCOR_DIAG] (
        ID int IDENTITY(1,1) NOT NULL,
        CREATED_DT datetime NOT NULL,
        SYSTEM_NAME nvarchar(1024),
	AGENTGUID nvarchar(1024),
        DIAG_TYPE nvarchar(50),
        BINARY_NAME nvarchar(1024),
        PARENT nvarchar(1024),
        TAG nvarchar(1024),
	RESTRICTED nvarchar(10),
        EXISTING_RULE nvarchar(1024),
	MANGLING_BYPASS nvarchar(10),
	CASP_BYPASS nvarchar(10),
	DEP_BYPASS nvarchar(10),
	primary key (ID)
    )
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_COMMAND_RESPONSE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
    create table  [dbo].[SCOR_COMMAND_RESPONSE] (
        ID int IDENTITY(1,1) NOT NULL,
        AGENTGUID uniqueidentifier,
        MACHINE_NAME nvarchar(255),
        TRANSACTION_ID nvarchar(255),
        COMMAND_RESULT nvarchar(max),
	TASK_NAME nvarchar(512),
	TASK_ID nvarchar(255),
	COMMAND_EXECUTED nvarchar(1024),
	COMMAND_RETURN_CODE numeric(10, 0),
	RESPONSE_COMPLETED numeric(1,0) default -1,
	COMMAND_START_TIME datetime,
	COMMAND_END_TIME datetime,
        primary key (ID)
    )
    create index SCOR_SCOR_COMMAND_RESPONSE_TRANSACTION_ID on [dbo].[SCOR_COMMAND_RESPONSE] (TRANSACTION_ID);
    create index SCOR_SCOR_COMMAND_RESPONSE_AGENTGUID on [dbo].[SCOR_COMMAND_RESPONSE] (AGENTGUID);
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DATA_CHANNEL]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
    create table  [dbo].[SCOR_DATA_CHANNEL] (
        ID int IDENTITY(1,1) NOT NULL,
        AGENTGUID uniqueidentifier NOT NULL,
        TRANSACTION_ID nvarchar(255) NOT NULL,
	DATA_TYPE nvarchar(255),
        SEQ_NO numeric(19,0) default 0,
        TOTAL_CHUNKS numeric(19,0) default 0,
        DATA nvarchar(max),
	TASK_NAME nvarchar(512),
	TASK_ID nvarchar(255),
	ANCHORED nchar(1) default 'N',
	COMMAND_EXECUTED nvarchar(1024),
	COMMAND_RETURN_CODE numeric(10, 0) DEFAULT 0,
	DETECTED_UTC datetime,
	RECEIVEDUTC datetime NOT NULL CONSTRAINT [DF_SCOR_DATA_CHANNEL_ReceivedUTC]  DEFAULT (getutcdate()),
	MACHINE_NAME nvarchar(255),
	COMPRESSED_DATA varbinary(max),
	COMPRESSION_TYPE tinyint DEFAULT 0,
	COMPRESSION_ALGO nvarchar(50),
        primary key (ID)
    )
    create NONCLUSTERED index SCOR_DATA_CHANNEL_IDX_COMPRESSION_TYPE ON [dbo].[SCOR_DATA_CHANNEL](COMPRESSION_TYPE);

END
GO


DECLARE @isStagingDataChannelPartitioned bit;
SET @isStagingDataChannelPartitioned = 0;
BEGIN TRY

	if (dbo.SCOR_FN_IS_PARTITIONING_SUPPORTED() = 1)
	BEGIN
		/* Create integer partition function for 100 partitions based on partition id, one partition for each partition id in the range 1-100 */
		if not exists (select 1 from sys.partition_functions where name = 'SCOR_STAGING_DATA_CHANNEL_PARTITION_FN')
		BEGIN
			DECLARE @DataChannelPartitionFunction nvarchar(max);
			SET @DataChannelPartitionFunction = N'CREATE PARTITION FUNCTION [SCOR_STAGING_DATA_CHANNEL_PARTITION_FN](int) AS RANGE RIGHT FOR VALUES (';
			DECLARE @i int;
			SET @i = 1;
			WHILE @i < 99
			BEGIN
			SET @DataChannelPartitionFunction = @DataChannelPartitionFunction + CAST(@i as nvarchar(10)) + N', ';
			SET @i = @i + 1;
			END
			SET @DataChannelPartitionFunction = @DataChannelPartitionFunction + CAST(@i as nvarchar(10)) + N');';
			EXEC sp_executesql @DataChannelPartitionFunction;
		END
		
		if not exists (select 1 from sys.partition_schemes where name = 'SCOR_STAGING_DATA_CHANNEL_PARTITION_SCHEME')
		BEGIN
			CREATE PARTITION SCHEME [SCOR_STAGING_DATA_CHANNEL_PARTITION_SCHEME]
			AS PARTITION [SCOR_STAGING_DATA_CHANNEL_PARTITION_FN] ALL TO ([PRIMARY])
		END
		
		if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_STAGING_DATA_CHANNEL]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
		BEGIN
			create table  [dbo].[SCOR_STAGING_DATA_CHANNEL] (
				ID int IDENTITY(1,1) NOT NULL,
				AGENTGUID uniqueidentifier NOT NULL,
				TRANSACTION_ID nvarchar(255) NOT NULL,
				DATA_TYPE nvarchar(255),
				SEQ_NO numeric(19,0) default 0,
				TOTAL_CHUNKS numeric(19,0) default 0,
				DATA nvarchar(max),
				TASK_NAME nvarchar(512),
				TASK_ID nvarchar(255),
				ANCHORED nchar(1) default 'N',
				COMMAND_EXECUTED nvarchar(1024),
				COMMAND_RETURN_CODE numeric(10, 0) DEFAULT 0,
				DETECTED_UTC datetime,
				RECEIVEDUTC datetime NOT NULL CONSTRAINT [SCOR_DF_STAGING_DATA_CHANNEL_ReceivedUTC]  DEFAULT (getutcdate()),
				MACHINE_NAME nvarchar(255),
				COMPRESSED_DATA varbinary(max),
				COMPRESSION_TYPE tinyint DEFAULT 0,
				COMPRESSION_ALGO nvarchar(50),
				PARTITION_ID int NOT NULL DEFAULT 1
			)  ON [SCOR_STAGING_DATA_CHANNEL_PARTITION_SCHEME](PARTITION_ID)
		    
			CREATE CLUSTERED INDEX [SCOR_STAGING_DATA_CHANNEL_PARTN_IDX_PARTITON_ID]
			ON [dbo].[SCOR_STAGING_DATA_CHANNEL] (PARTITION_ID)
			ON [SCOR_STAGING_DATA_CHANNEL_PARTITION_SCHEME](PARTITION_ID)
			
			ALTER TABLE [dbo].[SCOR_STAGING_DATA_CHANNEL] ADD constraint SCOR_PK_STAGING_DATA_CHANNEL_PARTITION_ID
			PRIMARY KEY NONCLUSTERED (ID ASC, PARTITION_ID ASC)
			ON [SCOR_STAGING_DATA_CHANNEL_PARTITION_SCHEME](PARTITION_ID)
			
			CREATE NONCLUSTERED INDEX [SCOR_STAGING_DATA_CHANNEL_PARTN_IDX_AGENTGUID]
			ON [dbo].[SCOR_STAGING_DATA_CHANNEL] (AGENTGUID ASC)
			ON [SCOR_STAGING_DATA_CHANNEL_PARTITION_SCHEME](PARTITION_ID)
			
			CREATE NONCLUSTERED INDEX [SCOR_STAGING_DATA_CHANNEL_PARTN_IDX_DATA_TYPE]
			ON [dbo].[SCOR_STAGING_DATA_CHANNEL] (DATA_TYPE ASC)
			ON [SCOR_STAGING_DATA_CHANNEL_PARTITION_SCHEME](PARTITION_ID)
			
			insert into SCOR_CONFIG(CONTEXT, NAME, VALUE, DEFAULT_VALUE, VALUE_TYPE, EDITABLE, VIEWABLE) VALUES ('general', 'isStagingDataChannelPartitioned', 'true', 'false', 'BOOLEAN', 'N', 'N');
			
			set @isStagingDataChannelPartitioned = 1;
		END		-- End table creatation
	END			-- End partition function, scheme and table creation
END TRY
BEGIN CATCH
	set @isStagingDataChannelPartitioned = 0;
END CATCH

if (@isStagingDataChannelPartitioned = 0)
BEGIN
	if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_STAGING_DATA_CHANNEL]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		create table  [dbo].[SCOR_STAGING_DATA_CHANNEL] (
			ID int IDENTITY(1,1) NOT NULL,
			AGENTGUID uniqueidentifier NOT NULL,
			TRANSACTION_ID nvarchar(255) NOT NULL,
			DATA_TYPE nvarchar(255),
			SEQ_NO numeric(19,0) default 0,
			TOTAL_CHUNKS numeric(19,0) default 0,
			DATA nvarchar(max),
			TASK_NAME nvarchar(512),
			TASK_ID nvarchar(255),
			ANCHORED nchar(1) default 'N',
			COMMAND_EXECUTED nvarchar(1024),
			COMMAND_RETURN_CODE numeric(10, 0) DEFAULT 0,
			DETECTED_UTC datetime,
			RECEIVEDUTC datetime NOT NULL CONSTRAINT [SCOR_DF_STAGING_DATA_CHANNEL_ReceivedUTC]  DEFAULT (getutcdate()),
			MACHINE_NAME nvarchar(255),
			COMPRESSED_DATA varbinary(max),
			COMPRESSION_TYPE tinyint DEFAULT 0,
			COMPRESSION_ALGO nvarchar(50),
			PARTITION_ID int NOT NULL DEFAULT 1,
			PRIMARY KEY (ID)
			)
	
		CREATE NONCLUSTERED INDEX [SCOR_STAGING_DATA_CHANNEL_IDX_AGENT_GUID]
		ON [dbo].[SCOR_STAGING_DATA_CHANNEL] (AGENTGUID ASC)
		
		CREATE NONCLUSTERED INDEX [SCOR_STAGING_DATA_CHANNEL_IDX_DATA_TYPE]
		ON [dbo].[SCOR_STAGING_DATA_CHANNEL] (DATA_TYPE ASC)
		
		insert into SCOR_CONFIG(CONTEXT, NAME, VALUE, DEFAULT_VALUE, VALUE_TYPE, EDITABLE, VIEWABLE) VALUES ('general', 'isStagingDataChannelPartitioned', 'false', 'false', 'BOOLEAN', 'N', 'N')
		
		CREATE NONCLUSTERED INDEX SCOR_STAGING_DATA_CHANNEL_DATATYPE_PARTITION_INDX
		ON [dbo].[SCOR_STAGING_DATA_CHANNEL] ([DATA_TYPE],[PARTITION_ID])
		
	END	-- End table creation
END 	-- End if
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_STAGING_DATA_CHANNEL_MAPPING]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_STAGING_DATA_CHANNEL_MAPPING]( 
				 ID int IDENTITY(1,1) NOT NULL, 
				 [AGENTGUID] [uniqueidentifier] NOT NULL,
				 [PARTITION_ID] [int] NOT NULL,
				 [ROLLUP_TIMESTAMP] [timestamp] NOT NULL,
				 primary key (ID)
			) 	
				 
	create index SCOR_IDX_STAGING_DATA_CHANNEL_MAPPING_AGENTGUID on [dbo].[SCOR_STAGING_DATA_CHANNEL_MAPPING] (AGENTGUID);
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_PUBLISHERS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_PUBLISHERS] (
	ID numeric(19,0) identity not null,
	 ISSUEDTO nvarchar(256),
	 PEM ntext not null,
	 ISSUEDBY nvarchar(256) null,
	 EXPDATE datetime null,
	 LASTMOD datetime null,
	 ISSUERKEY nvarchar(256) null,
	 PURPOSE nvarchar(256) null,
	 ALTRNAME nvarchar(256) null,
	 BINNAME nvarchar(256) null,
	 CERTSRC nvarchar(256) null,
	 primary key (ID));
ALTER TABLE [dbo].[SCOR_PUBLISHERS] add constraint SCOR_UNIQUE_ISSUER_KEY UNIQUE (ISSUERKEY);
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_APPLICATIONS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_APPLICATIONS] (
	ID numeric(19,0) identity not null,
	 APP_NAME nvarchar(1024),
	 VERSION nvarchar(100),
	 VENDOR nvarchar(254),
	 CHECKSUM nvarchar(254),
     BINNAME nvarchar(1024),
     [BINARY_SHA256] nvarchar(64),
	 primary key (ID));
ALTER TABLE [dbo].[SCOR_APPLICATIONS] add constraint SCOR_UNIQUE_CHKSUM UNIQUE  (CHECKSUM);
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_POLICY_GROUP]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_POLICY_GROUP] (
     ID int IDENTITY(1,1) NOT NULL,
     GROUP_NAME nvarchar(255) NOT NULL,
     GROUP_PLATFORM nvarchar(50) NOT NULL,
     GROUP_TYPE nvarchar(50) NOT NULL,
     IS_READ_ONLY nvarchar(20) NOT NULL default 'FALSE',
   primary key (ID)
)
alter table [dbo].[SCOR_POLICY_GROUP] add constraint UQ_SCOR_POLICY_GROUP UNIQUE (GROUP_NAME, GROUP_PLATFORM, GROUP_TYPE);
alter table [dbo].[SCOR_POLICY_GROUP] add constraint CK_VALIDATE_RULE_GROUP_NAME CHECK (rtrim(ltrim(GROUP_NAME)) != 'My Rules' );

END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_POLICY_GROUP_RULES]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_POLICY_GROUP_RULES] (
     ID int IDENTITY(1,1) NOT NULL,
     GROUP_ID int NOT NULL,
     RULE_ID int NOT NULL,
     RULE_NAME nvarchar(128) NOT NULL,
     RULE_VALUE nvarchar(3072) NOT NULL,
   primary key (ID)
)
ALTER TABLE [dbo].[SCOR_POLICY_GROUP_RULES] WITH CHECK ADD CONSTRAINT [FK_POLICY_GROUP_RULES_GROUP_ID] FOREIGN KEY([GROUP_ID]) REFERENCES [dbo].[SCOR_POLICY_GROUP] ([ID]) ON DELETE CASCADE
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_POLICY_GROUP_USER_ASSOC]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_POLICY_GROUP_USER_ASSOC] (
     ID int IDENTITY(1,1) NOT NULL,
     POLICY_GROUP_ID int NOT NULL,
     USER_ID int NOT NULL,
   primary key (ID)
)
ALTER TABLE [dbo].[SCOR_POLICY_GROUP_USER_ASSOC] WITH CHECK ADD CONSTRAINT [FK_POLICY_GROUP_USER_ASSOC_POLICY_GROUP_ID] FOREIGN KEY([POLICY_GROUP_ID]) REFERENCES [dbo].[SCOR_POLICY_GROUP] ([ID]) ON DELETE CASCADE
ALTER TABLE [dbo].[SCOR_POLICY_GROUP_USER_ASSOC]  ADD CONSTRAINT UC_POLICY_GROUP_USER_ASSOC_POLICY_GROUP_ID_USER_ID UNIQUE (POLICY_GROUP_ID,USER_ID)
END
GO

if (dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_IMAGE_DEVIATION_HISTORY') = 0)
BEGIN
create table [dbo].[SCOR_IMAGE_DEVIATION_HISTORY](
	[ID] int IDENTITY(1,1) NOT NULL,
	[GOLD_SYSTEM_NAME] nvarchar (255) NOT NULL,
	[TARGET_SYSTEM_NAME] nvarchar (255) NOT NULL,
	[GOLD_SYSTEM_GROUP_NODE_PATH] nvarchar (2048) NOT NULL,
	[TARGET_SYSTEM_GROUP_NODE_PATH] nvarchar (2048) NOT NULL,
	[GOLD_AGENTGUID] uniqueidentifier NOT NULL,
	[TARGET_AGENTGUID] uniqueidentifier NOT NULL,
	[GOLD_INV_FETCH_TIME] smalldatetime NOT NULL,
	[TARGET_INV_FETCH_TIME] smalldatetime NOT NULL,
	[NUM_ADDED_DEVIATIONS] int NOT NULL,
	[NUM_DELETED_DEVIATIONS] int NOT NULL,
	[NUM_MODIFIED_DEVIATIONS] int NOT NULL,
	[NUM_EXEC_ALLOWED_DEVIATIONS] int NOT NULL,
	[IMAGE_DEV_RUN_TIME] smalldatetime NOT NULL DEFAULT (getutcdate()),
	[ROLLUP_TIMESTAMP] rowversion NOT NULL,
	primary key (ID)
);
create index SCOR_IMAGE_DEVIATION_HISTORY_TARGET_AGENTGUID_IDX on [dbo].[SCOR_IMAGE_DEVIATION_HISTORY] (TARGET_AGENTGUID);
create index SCOR_IMAGE_DEVIATION_HISTORY_IMAGE_DEV_RUN_TIME_IDX on [dbo].[SCOR_IMAGE_DEVIATION_HISTORY] (IMAGE_DEV_RUN_TIME);
END
GO

if (dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_IMAGE_DEVIATION_HISTORY_DETAILS') = 0)
BEGIN
create table [dbo].[SCOR_IMAGE_DEVIATION_HISTORY_DETAILS](
	[ID] int IDENTITY(1,1) NOT NULL,
	[IMAGE_DEV_HISTORY_ID] int NOT NULL,
	[GOLD_BINARY_ID] int NULL,
	[TARGET_BINARY_ID] int NULL,
	[FILE_PATH] nvarchar(4000) NOT NULL,
	[GOLD_FILE_EXECUTION_ALLOWED] bit NOT NULL,
	[TARGET_FILE_EXECUTION_ALLOWED] bit NOT NULL,
	[DEVIATION_TYPE] tinyint NOT NULL,
	[ROLLUP_TIMESTAMP] rowversion NOT NULL,
	primary key (ID)
);
ALTER TABLE [dbo].[SCOR_IMAGE_DEVIATION_HISTORY_DETAILS] WITH CHECK ADD CONSTRAINT [FK_SCOR_IMAGE_DEVIATION_HISTORY_DETAILS_IMAGE_DEV_HISTORY_ID] FOREIGN KEY([IMAGE_DEV_HISTORY_ID]) REFERENCES [dbo].[SCOR_IMAGE_DEVIATION_HISTORY] ([ID]) ON DELETE CASCADE;
ALTER TABLE [dbo].[SCOR_IMAGE_DEVIATION_HISTORY_DETAILS] WITH CHECK ADD CONSTRAINT [FK_SCOR_IMAGE_DEVIATION_HISTORY_DETAILS_GOLD_BINARY_ID] FOREIGN KEY([GOLD_BINARY_ID]) REFERENCES [dbo].[SCOR_INV_BINARIES] ([BINARY_ID]) ON DELETE NO ACTION;
ALTER TABLE [dbo].[SCOR_IMAGE_DEVIATION_HISTORY_DETAILS] WITH CHECK ADD CONSTRAINT [FK_SCOR_IMAGE_DEVIATION_HISTORY_DETAILS_TARGET_BINARY_ID] FOREIGN KEY([TARGET_BINARY_ID]) REFERENCES [dbo].[SCOR_INV_BINARIES] ([BINARY_ID]) ON DELETE NO ACTION;

create index SCOR_IMAGE_DEVIATION_HISTORY_DETAILS_IMAGE_DEV_HISTORY_ID_DEVIATION_TYPE_COMPOSITE_IDX 
	on [dbo].[SCOR_IMAGE_DEVIATION_HISTORY_DETAILS] (IMAGE_DEV_HISTORY_ID, TARGET_BINARY_ID, GOLD_BINARY_ID) INCLUDE (DEVIATION_TYPE);

CREATE NONCLUSTERED INDEX [SCOR_IDX_SCOR_IMAGE_DEVIATION_HISTORY_DETAILS_BINARY_ID_COLUMNS_COMPOSITE_IDX ] ON [dbo].[SCOR_IMAGE_DEVIATION_HISTORY_DETAILS] 
(
	[GOLD_BINARY_ID] ASC,
	[TARGET_BINARY_ID] ASC
);

CREATE NONCLUSTERED INDEX [SCOR_IMAGE_DEVIATION_HISTORY_DETAILS_TARGET_BINARY_ID ] ON [dbo].[SCOR_IMAGE_DEVIATION_HISTORY_DETAILS] 
(
	[TARGET_BINARY_ID] ASC
);
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_TASK_CLEANUP_REGISTRY]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_TASK_CLEANUP_REGISTRY](
	[ID] int IDENTITY (1,1) NOT NULL,
	[TASK_ID] int NOT NULL,
	[OWNING_CLASS_KEY] varchar(256) NULL,
	[TASK_START_TIME] smalldatetime NOT NULL,
	primary key (ID)
	);
END 
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_OBSERVATIONS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_OBSERVATIONS](
	[AUTO_ID] int IDENTITY(1,1) NOT NULL,
	[AGENTGUID] uniqueidentifier NOT NULL,
	[BINARY_CKSUM] varchar(64),
	[BINARY_NAME] nvarchar(256),
	[ACTIVEX_NAME] nvarchar(1024),
	[ACTIVEX_FILE_NAMES] nvarchar(2048),
	[BINARY_PARENT_ID] int,
	[BINARY_TYPE] nvarchar(64),
	[CERTIFICATE] varchar(max),
	[DENY_REASON] varchar(1024),
	[DETECTED_UTC] datetime NOT NULL,
	[EXPLOIT_TYPE] varchar(1024),
	[RECEIVED_UTC] datetime NOT NULL CONSTRAINT [SCOR_OBSERVATIONS_RECEIVED_UTC]  DEFAULT (getutcdate()),
	[IS_INSTALLER] bit NULL default 0,
	[IS_PARENT_INTERPRETER] bit NULL default 0,
	[IS_SYSTEM_FILE] bit NULL default 0,
	[IS_NETWORK_PATH] bit NULL default 0,
	[OBSERVATION_TYPE] varchar(256) NOT NULL,
	[PROCESS_ID] int,
	[APPROVAL_STATUS] int NULL default 0,
	[REMARKS] nvarchar(512),
	[PARENT_AUTO_ID] int,
	[IS_ROOT] bit default 0,
	[ROOT_AUTO_ID] int,
	[USER_NAME] nvarchar(512),
	[HOST_NAME] nvarchar(256),
	ROLLUP_TIMESTAMP [rowversion] NOT NULL,
	primary key (AUTO_ID)
    );
    
CREATE NONCLUSTERED INDEX [SCOR_OBSERVATIONS_DETECTED_UTC_INDEX] ON [dbo].[SCOR_OBSERVATIONS] 
(
	[DETECTED_UTC] ASC
) INCLUDE ( [AGENTGUID],[APPROVAL_STATUS],[IS_ROOT],[BINARY_NAME],[ACTIVEX_NAME],[OBSERVATION_TYPE]);

    
CREATE NONCLUSTERED INDEX [SCOR_OBSERVATIONS_PARENT_AUTO_ID_INDEX] ON [dbo].[SCOR_OBSERVATIONS] 
(
	[PARENT_AUTO_ID] ASC
); 

CREATE NONCLUSTERED INDEX [SCOR_OBSERVATIONS_SIMILAR_OBSERVATIONS_INDEX] ON [dbo].[SCOR_OBSERVATIONS] 
(
	[IS_ROOT] ASC,
	[APPROVAL_STATUS] ASC,
	[OBSERVATION_TYPE] ASC
) INCLUDE ( [BINARY_CKSUM],[BINARY_NAME],[ACTIVEX_NAME],[AGENTGUID]);

CREATE NONCLUSTERED INDEX [SCOR_OBSERVATIONS_AGENTGUID_INDEX] ON [dbo].[SCOR_OBSERVATIONS] 
(
	[AGENTGUID] ASC
);

END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_OBSERVATION_FILTERS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_OBSERVATION_FILTERS](
	[AUTO_ID] int IDENTITY(1,1) NOT NULL,
	[FILTER_TAG] nvarchar(1024),
	[FILTER_NAME] nvarchar(256),
	[OBSERVATION_TYPE] varchar(256) NOT NULL,
	[PARENT_BASE_NAME] nvarchar(256),
	ROLLUP_TIMESTAMP [rowversion] NOT NULL,
	primary key (AUTO_ID)
    );
END
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_OBSERVATION_STATISTICS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_OBSERVATION_STATISTICS](
	[AUTO_ID] int IDENTITY(1,1) NOT NULL,
	[PARENT_PROCESS_NAME] nvarchar(256),
	[BINARY_NAME] nvarchar(256),
	[OBSERVATION_TYPE] nvarchar(256),
	[COUNT] int NOT NULL,
	[SUGGESTION] int default 0,
	[BINARY_INFO] varchar(max),
	[ACTION_TAKEN] int NULL default 0,
	[LAST_MODIFIED_UTC] datetime NOT NULL CONSTRAINT [SCOR_OBSERVATION_STATISTICS_LAST_MODIFIED_UTC]  DEFAULT (getutcdate()),
	ROLLUP_TIMESTAMP [rowversion] NOT NULL,
	primary key (AUTO_ID)
    );
END
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_FD_DATA_CHANNEL]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_FD_DATA_CHANNEL] (
    ID int IDENTITY(1,1) NOT NULL,
    AGENTGUID uniqueidentifier NOT NULL,
    TRANSACTION_ID nvarchar(255) NOT NULL,
    SEQ_NO int default 0,
    TOTAL_CHUNKS int default 0,
	FILE_DATA nvarchar(max),
	META_DATA nvarchar(max),
	FIRST_EVT_SEQ_NO numeric(19,0),
	LAST_EVT_SEQ_NO numeric(19,0),
	FILE_NAME_PATH  nvarchar(4000) NOT NULL,
	OLD_FILE_NAME nvarchar(4000) null,
	NEW_FILE_NAME nvarchar(4000) null,
	EVENT_TYPE nvarchar(256),
	FILE_STATUS int DEFAULT -1,
	DETECTED_UTC datetime,
	RECEIVED_UTC datetime NOT NULL CONSTRAINT [SCOR_DF_FD_DATA_CHANNEL_ReceivedUTC]  DEFAULT (getutcdate()),
	MODIFIED_BY nvarchar(512),
	PROGRAM nvarchar(4000),
	WORKFLOW_ID nvarchar(256),
	FILE_ENCODING nvarchar(256) default 'AutoDetect',
    primary key (ID)
 );
 CREATE NONCLUSTERED INDEX [SCOR_FD_DATACHANNEL_COV_AG_DU_SN_TI] ON [dbo].[SCOR_FD_DATA_CHANNEL] ([AGENTGUID], [DETECTED_UTC], [SEQ_NO], [TRANSACTION_ID]);
END
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_FD_FILE_INFO]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_FD_FILE_INFO] (
    ID int IDENTITY(1,1) NOT NULL,
    AGENTGUID uniqueidentifier not null,
	SYSTEM_NAME nvarchar(256),
    FILE_NAME_PATH nvarchar(4000) not null,
    FILE_STATUS int DEFAULT -1,
	LATEST_FILE_VERSION int NOT NULL default 0,
	ROLLUP_TIMESTAMP [rowversion] NOT NULL,
	LAST_MODIFIED_TIME datetime,
    primary key(ID)
)
ALTER TABLE [dbo].[SCOR_FD_FILE_INFO]  ADD CONSTRAINT UC_SCOR_AGENTGUID_FILE_NAME_PATH UNIQUE (AGENTGUID,FILE_NAME_PATH)

END
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_FD_FILE_REPOS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_FD_FILE_REPOS] (
    ID int IDENTITY(1,1) NOT NULL,
    FD_FI_ID int NOT NULL,
    FIRST_EVT_SEQ_NO numeric(19,0) NOT NULL default 0,
    LAST_EVT_SEQ_NO numeric(19,0) NOT NULL default 0,
    METADATA nvarchar(max),
    FILEDATA varbinary(max),
	FILE_ENCODING nvarchar(256) NOT NULL default 'AutoDetect',
    VERSION int NOT NULL,
    IS_BASE_REVISION bit NOT NULL default 0,
    MODIFIED_BY nvarchar(512),
	EVENT_TYPE nvarchar(256),
    PROGRAM nvarchar(4000),
    WORKFLOW_ID nvarchar(256),
    DETECTED_UTC datetime,
    RECEIVED_UTC datetime NOT NULL CONSTRAINT [SCOR_DF_FD_FILE_REPOS_RECEIVED_UTC_DEFAULT]  DEFAULT (getutcdate()),
	ROLLUP_TIMESTAMP [rowversion] NOT NULL,	
    primary key(ID)
)

alter table [dbo].[SCOR_FD_FILE_REPOS] add constraint SCOR_FD_FILE_REPOS_FI_ID
    foreign key (FD_FI_ID) references  [dbo].[SCOR_FD_FILE_INFO] ON DELETE CASCADE ON UPDATE CASCADE;
	
create index SCOR_FD_FILE_REPOS_FD_FI_ID on [dbo].[SCOR_FD_FILE_REPOS] (FD_FI_ID);	
create index SCOR_FD_FILE_REPOS_EVENT_TYPE on [dbo].[SCOR_FD_FILE_REPOS] (EVENT_TYPE);

END
GO

if (dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_COMMON_BINARY_INFO') = 0)
BEGIN
	CREATE TABLE [dbo].[SCOR_COMMON_BINARY_INFO](
                [AUTO_ID] int IDENTITY(1,1) NOT NULL,
                [BINARY_SHA1] varchar(64) NOT NULL,
				[BINARY_MD5] varchar(32) NULL,
                [BINARY_TYPE] nvarchar(64) NULL,
                [BINARY_APP_NAME] nvarchar(256) NULL,
                [BINARY_APP_VENDOR] nvarchar(256) NULL,
                [BINARY_APP_VERSION] nvarchar(64) NULL,
                [BINARY_VERSION] nvarchar(64) NULL,
				[BINARY_SIZE] bigint  NOT NULL,
                [PUBLISHER_ID] int NULL,
                [IS_INSTALLER] bit NULL default 0,
                [IS_SYSTEM_FILE] bit NULL default 0,              
				ROLLUP_TIMESTAMP [rowversion] NOT NULL,
				BINARY_REPUTATION_ID int NULL,
				[CERTIFICATE_STATUS] tinyint NOT NULL default 1,
				[BINARY_SHA256] varchar(64) NULL,
                primary key (AUTO_ID)
    );
    CREATE INDEX [SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA1] ON [dbo].[SCOR_COMMON_BINARY_INFO] ([BINARY_SHA1]);
    CREATE NONCLUSTERED INDEX [SCOR_IDX_COMMON_BINARY_INFO_REPUTATION_ID] ON [dbo].[SCOR_COMMON_BINARY_INFO] ([BINARY_REPUTATION_ID]);
    CREATE INDEX [SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA256] ON [dbo].[SCOR_COMMON_BINARY_INFO] ([BINARY_SHA256]);
 END 
 GO
	
if (dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 0)
BEGIN
	CREATE TABLE [dbo].[SCOR_SA_REQUEST](
		[AUTO_ID] int IDENTITY(1,1) NOT NULL,
		[AGENTGUID] uniqueidentifier NOT NULL,
		[APPROVAL_TAG] nvarchar(256) NOT NULL,
		[EVENT_TYPE] varchar(64) NULL,
		[USERS_COMMENTS] nvarchar(4000),
		[USER_NAME] nvarchar(512),
		[APPROVAL_STATUS] int NULL default 0,
		[BINARY_INFO_ID] int NULL,
		[RULE_GROUP_ID] int NULL,
		[PARENT_PROCESS_NAME] nvarchar(256),
		[OBJECT_NAME] nvarchar(4000) NULL,
		[IS_CRITICAL_PROCESS] bit NOT NULL,
		[USER_ACTION] varchar(64) NULL,
		[FILES_CHANGED] nvarchar(4000),
		[ACTIVITY] tinyint NOT NULL,
		[DETECTED_UTC] datetime NOT NULL,
		[RECEIVED_UTC] datetime NOT NULL CONSTRAINT [SCOR_SA_RECEIVED_UTC]  DEFAULT (getutcdate()),
		[MODE] tinyint NOT NULL DEFAULT 2 ,
		[CHECKSUM] varchar(40) NULL,
		[GROUPED_REQ_ID] int NULL,
        [BINARY_PATH] nvarchar(4000) NULL,
        [BINARY_BASE_NAME] nvarchar(256) NULL,
		[IS_NETWORK_PATH] bit NOT NULL default 0,
		[IS_MP_VIOLATION] bit NOT NULL default 0,
		[HOST_NAME] nvarchar(256),
        ROLLUP_TIMESTAMP [rowversion] NOT NULL,
        BINARY_SHA256 varchar(64) NULL,
        
                primary key (AUTO_ID)
    );
alter table [dbo].[SCOR_SA_REQUEST] add constraint SCOR_COMMON_BINARY_INFO_SCOR_SA_REQUEST
  foreign key ([BINARY_INFO_ID]) references  [dbo].[SCOR_COMMON_BINARY_INFO] ([AUTO_ID]);
ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD CONSTRAINT UC_SCOR_AGENTGUID_APPROVAL_TAG UNIQUE (APPROVAL_TAG);
CREATE INDEX [SCOR_SA_REQUEST_GR_REQ_ID_STATUS] ON [dbo].[SCOR_SA_REQUEST] ([GROUPED_REQ_ID] ASC, [APPROVAL_STATUS] ASC);
create index SCOR_SA_REQUEST_BINARY_INFO_ID on [dbo].[SCOR_SA_REQUEST] (BINARY_INFO_ID); 
CREATE INDEX [SCOR_SA_REQUEST_AGENTGUID] ON [dbo].[SCOR_SA_REQUEST] ([AGENTGUID]) INCLUDE ([GROUPED_REQ_ID]);
CREATE INDEX [SCOR_SA_REQUEST_DETECTED_UTC_STATUS] ON [dbo].[SCOR_SA_REQUEST] ([DETECTED_UTC], [APPROVAL_STATUS]) INCLUDE ([AGENTGUID],[GROUPED_REQ_ID],[BINARY_BASE_NAME],[ACTIVITY]);
END
GO

if (dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_GROUPED_REQUEST') = 0)
BEGIN
	CREATE TABLE [dbo].[SCOR_SA_GROUPED_REQUEST](
		[AUTO_ID] int IDENTITY(1,1) NOT NULL,
		[CHECKSUM] varchar(40) NOT NULL,
        [DETECTED_UTC] datetime NOT NULL, 
		[ACTIVITY] tinyint NOT NULL,
		[FILE_NAME] nvarchar(4000) NULL,
        [APP_NAME] nvarchar(256) NULL,
		[ISSUED_TO] nvarchar(256) NULL,
		[PREVALANCE] int NOT NULL default 0,
		[APPROVAL_STATUS_PENDING] bit NOT NULL default 0,
		[APPROVAL_STATUS_ALLOWED] bit NOT NULL default 0,
        [APPROVAL_STATUS_BANNED] bit NOT NULL default 0,
        [IS_INSTALLER] bit NOT NULL default 0,
		[BINARY_INFO_ID] int NOT NULL, 
		[IS_MP_VIOLATION] bit NOT NULL default 0,
		[PREVALANCE_PENDING] int NOT NULL default 0,  
		[PREVALANCE_ALLOWED] int NOT NULL default 0,
		[PREVALANCE_BANNED] int NOT NULL default 0,
		ROLLUP_TIMESTAMP [rowversion] NOT NULL,
		BINARY_REPUTATION_ID int NULL,
		USER_COMMENT nvarchar(4000) NULL,
		BINARY_SHA256 varchar(64) NULL,
                primary key (AUTO_ID)
    );
    
 CREATE INDEX [SCOR_SA_GROUPED_REQUEST_DET_UTC] ON [dbo].[SCOR_SA_GROUPED_REQUEST] ([DETECTED_UTC] ASC) include ([FILE_NAME], [APP_NAME], [PREVALANCE],
 [APPROVAL_STATUS_PENDING], [APPROVAL_STATUS_ALLOWED], [APPROVAL_STATUS_BANNED]);
  CREATE INDEX [SCOR_SA_GROUPED_REQUEST_CHECKSUM] ON [dbo].[SCOR_SA_GROUPED_REQUEST] ([CHECKSUM] ASC) include (IS_MP_VIOLATION);
  CREATE INDEX [SCOR_SA_GROUPED_REQUEST_BINARY_SHA256] ON [dbo].[SCOR_SA_GROUPED_REQUEST] ([BINARY_SHA256] ASC) include (IS_MP_VIOLATION);
  CREATE NONCLUSTERED INDEX [SCOR_IDX_SCOR_SA_GROUPED_REQUEST_REPUTATION_ID] ON [dbo].[SCOR_SA_GROUPED_REQUEST] ([BINARY_REPUTATION_ID]);

END 
GO
	
if (dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_RULES') = 0)
BEGIN
	CREATE TABLE [dbo].[SCOR_SA_RULES](
                [AUTO_ID] int IDENTITY(1,1) NOT NULL,
                [BINARY_INFO_ID] int NOT NULL,
                [SA_REQUEST_ID] int NOT NULL,
                [EVENT_TYPE] varchar(400) NOT NULL,
                [SA_ACTION] varchar(256) NOT NULL,
                [DETECTED_UTC] datetime NOT NULL,
                [RECEIVED_UTC] datetime NOT NULL CONSTRAINT [SCOR_SELF_APPROVAL_RULES]  DEFAULT (getutcdate()),
                [CHECKSUM] varchar(40) NULL,
                [GROUPED_REQ_ID] int NULL,
        		[BINARY_PATH] nvarchar(4000) NULL,
        		[BINARY_PATH_TRIMMED] nvarchar(4000) NULL,
        		[BINARY_BASE_NAME] nvarchar(256) NULL,
				[IS_NETWORK_PATH] bit NOT NULL default 0,
                ROLLUP_TIMESTAMP [rowversion] NOT NULL,
                BINARY_SHA256 varchar(64) NULL,
                primary key (AUTO_ID)
    );
 alter table [dbo].[SCOR_SA_RULES] add constraint SCOR_COMMON_BINARY_INFO_SCOR_SA_RULES
   foreign key ([BINARY_INFO_ID]) references  [dbo].[SCOR_COMMON_BINARY_INFO] ([AUTO_ID]);
 alter table [dbo].[SCOR_SA_RULES] add constraint SCOR_SA_REQUEST_SCOR_SA_RULES
   foreign key ([SA_REQUEST_ID]) references  [dbo].[SCOR_SA_REQUEST] ([AUTO_ID]) ON DELETE CASCADE ON UPDATE CASCADE;

create index SCOR_SA_RULES_SA_REQUEST_ID on [dbo].[SCOR_SA_RULES] (SA_REQUEST_ID); 

create index SCOR_SA_RULES_BINARY_INFO_ID on [dbo].[SCOR_SA_RULES] (BINARY_INFO_ID); 

CREATE INDEX [SCOR_SA_RULE_GROUPED_REQ_ID] ON [dbo].[SCOR_SA_RULES] ([GROUPED_REQ_ID] ASC)
INCLUDE ( [AUTO_ID],[EVENT_TYPE],[SA_ACTION],[CHECKSUM],[BINARY_INFO_ID],[BINARY_PATH],[IS_NETWORK_PATH], [BINARY_SHA256]) ;

END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_BINARY_REPUTATION]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_BINARY_REPUTATION] (
	[AUTO_ID] int IDENTITY(1,1) NOT NULL,
	[SHA1] varchar(40) NOT NULL,
	[SHA2] varchar(64) NULL,
	[MD5] varchar(32) NULL,
	[MAC_ETL] int NULL,
	[GTI_SCORE_ACTUAL] int NULL,
	[GTI_SCORE_MAPPED] int NULL,
	[GTI_TRUST_LEVEL] tinyint NULL,
	[TIE_ETL_SCORE_ACTUAL] int NULL,
	[ATD_SCORE_ACTUAL] int NULL,
	[EFFECTIVE_LEVEL] tinyint NOT NULL DEFAULT 50,
	[EFFECTIVE_LEVEL_REASON] tinyint NOT NULL DEFAULT 4,
	[GTI_TTL_EXPIRY_UTC] datetime NULL,
	[GTI_CLASSIFICATION] nvarchar(32) NULL,
	[GTI_IS_SYSTEM_FILE] bit NULL default 0,
	[GTI_IS_INSTALLER] bit NULL default 0,
    [LAST_UPDATE_TRUST_SOURCE] tinyint NOT NULL DEFAULT 0,
    [LAST_UPDATE_TIME_TIE_UTC] datetime NULL,
    [LAST_UPDATE_TIME_GTI_UTC] datetime NULL,
    [FIRST_MACC_FEATURE_SOURCE] tinyint NOT NULL DEFAULT 0,
    [IS_TIE_UPDATE_PENDING] bit NOT NULL default 0,
    [CUSTOM_1] nvarchar(2000) NULL,
    [CUSTOM_2] nvarchar(2000) NULL,
    [CUSTOM_3] tinyint NULL,
    [CUSTOM_4] tinyint NULL,
	[ROLLUP_TIMESTAMP] rowversion NOT NULL,
	[CERT_ID] int NULL,
    [ORIGINAL_REPUTATION_REASON] tinyint NOT NULL Default 0,
	primary key (AUTO_ID));
	ALTER TABLE [dbo].[SCOR_BINARY_REPUTATION]  ADD CONSTRAINT UC_SCOR_BINARY_REPUTATION_SHA1 UNIQUE (SHA1);
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_ASYNC_JOB]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_ASYNC_JOB] (
	[AUTO_ID] int IDENTITY(1,1) NOT NULL,
	[CONTEXT] nvarchar(128) NOT NULL,
	[JOB_TYPE] nvarchar(128) NOT NULL,
	[CONTEXT_DATA] nvarchar(max) NULL,
	[MORE_INFO] nvarchar(max) NULL,
	[JOB_CREATION_UTC] datetime NULL CONSTRAINT [DF_SCOR_ASYNC_JOB_CREATION_UTC]  DEFAULT (getutcdate()),
	[ATTEMPT_INTERVAL_SECONDS] int NULL,
	[NEXT_ATTEMPT_UTC] datetime NULL,
	[JOB_EXPIRY_UTC] datetime null,
	primary key (AUTO_ID));
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CERTIFICATE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_CERTIFICATE] (
	[ID] int identity NOT  NULL,
    [SUBJECT] nvarchar(256) NOT NULL,
    [PEM] nvarchar(MAX) NULL,
    [ISSUED_BY] nvarchar(256) NOT NULL,
    [ISSUER_SHA1] varchar(40) NULL,
    [LAST_MODIFIED] datetime NULL,
    [PURPOSE] nvarchar(256) NULL,
    [FIRST_FEATURE_SOURCE] tinyint NOT NULL DEFAULT 0,
    [PUBLIC_KEY_HASH] varchar(64) NOT NULL,
    [PUBLIC_KEY_HASH_ALGO] varchar(30) NOT NULL,
    [PUBLIC_KEY_ALGO] varchar(30) NOT NULL,
    [PUBLIC_KEY_LENGTH] int NULL,
    [CERT_HASH] varchar(64) NOT NULL,
    [CERT_HASH_ALGO] varchar(30) NOT NULL,
    [CERT_VERSION] varchar(30) NULL,
    [SIGNATURE_ALGO] varchar(50) NULL,
    [SIGNATURE_HASH_ALGO] varchar(50) NULL,
	[VALID_FROM] datetime NULL,
    [VALID_TO] datetime NULL,
    [SERIAL_NUMBER] varchar(250) NULL,
	[CERT_REPUTATION_ID] int NULL,
	primary key (ID));
ALTER TABLE [dbo].[SCOR_CERTIFICATE] add constraint SCOR_UNIQUE_CERT_HASH UNIQUE (CERT_HASH);
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CERT_REPUTATION]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_CERT_REPUTATION] (
	[AUTO_ID] int IDENTITY(1,1) NOT NULL,
    [CERT_HASH] varchar(64) NOT NULL,
    [PUBLIC_KEY_HASH] varchar(64)  NULL,
    [GTI_SCORE] int NULL,
    [GTI_REPUTATION] tinyint NULL,
    [TIE_GTI_SCORE] int NULL,
    [TIE_ETL_SCORE] int NULL,
    [EFFECTIVE_REPUTATION] tinyint NOT NULL DEFAULT 50, 
    [EFFECTIVE_REPUTATION_REASON] tinyint NOT NULL DEFAULT 4,
    [GTI_TTL_EXPIRY_UTC] datetime NULL,
    [LAST_UPDATE_TIME_TIE_UTC] datetime NULL,
    [LAST_UPDATE_TIME_GTI_UTC] datetime NULL,
    [TIE_ETL_ATTRIBUTES] nvarchar(max) NULL,
	[TIE_GTI_ATTRIBUTES] nvarchar(max) NULL,
	[LAST_UPDATE_TRUST_SOURCE] tinyint NOT NULL DEFAULT 0,
    [ROLLUP_TIMESTAMP] rowversion NOT NULL,
	primary key (AUTO_ID));
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_BINARY_REPUTATION_CERT_ASSOC]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
create table [dbo].[SCOR_BINARY_REPUTATION_CERT_ASSOC] (
	[AUTO_ID] int IDENTITY(1,1) NOT NULL,
    [BINARY_REPUTATION_ID] int NOT NULL,
    [CERT_ID] int NOT NULL,
    [SIGNING_TYPE] tinyint NOT NULL DEFAULT 0, 
	primary key (AUTO_ID));
create index SCOR_IDX_BINARY_REPUTATION_CERT_ASSOC_BIN_REP_ID on [dbo].[SCOR_BINARY_REPUTATION_CERT_ASSOC] (BINARY_REPUTATION_ID); 
END
GO

/*#start# upgrade statements from 5.0.2 to 5.1.0.*/
/* In case of upgrade check for the existence of THETIMESTAMP column in SCOR_EVENTS Table.Add THETIMESTAMP column if does not exist*/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_EVENTS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	if not exists (select 1 from sys.syscolumns where name='ROLLUP_TIMESTAMP' and id=object_id(N'[DBO].[SCOR_EVENTS]'))
	BEGIN
		ALTER TABLE [dbo].[SCOR_EVENTS] ADD ROLLUP_TIMESTAMP [rowversion] NOT NULL
	END
END

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_PUBLISHERS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	if not exists (select 1 from sys.syscolumns where name='LASTMOD' and id=object_id(N'[DBO].[SCOR_PUBLISHERS]'))
	BEGIN
		ALTER TABLE [dbo].[SCOR_PUBLISHERS] ADD LASTMOD datetime
	END

	if not exists (select 1 from sys.syscolumns where name='BINNAME' and id=object_id(N'[DBO].[SCOR_PUBLISHERS]'))
	BEGIN
		ALTER TABLE [dbo].[SCOR_PUBLISHERS] ADD BINNAME nvarchar(256) null
	END

	if not exists (select 1 from sys.syscolumns where name='CERTSRC' and id=object_id(N'[DBO].[SCOR_PUBLISHERS]'))
	BEGIN
		ALTER TABLE [dbo].[SCOR_PUBLISHERS] ADD CERTSRC nvarchar(256) null
	END
END

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_APPLICATIONS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	if not exists (select 1 from sys.syscolumns where name='BINNAME' and id=object_id(N'[DBO].[SCOR_APPLICATIONS]'))
	BEGIN
		ALTER TABLE [dbo].[SCOR_APPLICATIONS] ADD BINNAME nvarchar(1024)
	END
END

GO

--Update Events table, removing extra columns.
BEGIN
if (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_EVENTS', 'ACTION' ) = 1)
	alter table [dbo].[SCOR_EVENTS] drop column ACTION;
if (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_EVENTS', 'EVT_MODOFICATION' ) = 1)
	alter table [dbo].[SCOR_EVENTS] drop column EVT_MODOFICATION;
END
GO

/*#End# upgrade statements from 5.0.2 to 5.1.0.*/

/*#start# upgrade statements from 5.1.0 to 5.1.1.*/
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) AND (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_EVENTS', 'EPO_EVENT_AUTO_ID' ) = 0))
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD EPO_EVENT_AUTO_ID int NULL;
	ALTER TABLE [dbo].[SCOR_EVENTS] add constraint SCOR_EVENTS_EPO_EVENTS
    foreign key (EPO_EVENT_AUTO_ID) references  [dbo].[EpoEvents] ON DELETE CASCADE ON UPDATE CASCADE;
END

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENT_INFO') = 1) AND (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_EVENT_INFO', 'THREAT_HANDLED' ) = 0))
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENT_INFO] ADD THREAT_HANDLED bit NULL;
END

GO

/*#End# upgrade statements from 5.1.0 to 5.1.1.*/

/*#start# upgrade statements from 5.1.1 to 5.1.2*/
BEGIN
if (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_EVENTS', 'EVT_KEY_NAME' ) = 1)
	alter table [dbo].[SCOR_EVENTS] drop column EVT_KEY_NAME;
if (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_ROLLUP_EVENTS', 'EVT_KEY_NAME' ) = 1)
	alter table [dbo].[SCOR_ROLLUP_EVENTS] drop column EVT_KEY_NAME;
END
GO
/*#End# upgrade statements from 5.1.1 to 5.1.2.*/

/*#start# upgrade statements from 5.1.3 to 6.0.0*/
[dbo].[SCOR_DROP_TABLE] [SCOR_IMAGE_DEVIATION_SUMMARY]
GO
[dbo].[SCOR_DROP_TABLE] [SCOR_IMAGE_DEVIATION_DETAILS]
GO
[dbo].[SCOR_DROP_TABLE] [SCOR_FIDB]
GO
[dbo].[SCOR_DROP_TABLE] [SCOR_FIDB_SEARCH_TABLE_1]
GO
[dbo].[SCOR_DROP_TABLE] [SCOR_FIDB_SEARCH_TABLE_2]
GO
[dbo].[SCOR_DROP_TABLE] [SCOR_SKU_FEATURE_MAPPING]
GO

BEGIN

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENT_INFO') = 1) AND (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_EVENT_INFO', 'FD_SUPPORT' ) = 0))
	ALTER TABLE [dbo].[SCOR_EVENT_INFO] ADD FD_SUPPORT TINYINT NOT NULL CONSTRAINT SCOR_EVENT_INFO_FD_SUPPORT_DEF default 0;
END
GO

BEGIN
if (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_CONFIG', 'VALUE') = 1)
	ALTER TABLE [dbo].[SCOR_CONFIG] ALTER COLUMN VALUE nvarchar(MAX);
END
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_RECON_TICKET2]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	if not exists (select 1 from sys.syscolumns where name='ROLLUP_TIMESTAMP' and id=object_id(N'[DBO].[SCOR_RECON_TICKET2]'))
	BEGIN
		ALTER TABLE [dbo].[SCOR_RECON_TICKET2] ADD ROLLUP_TIMESTAMP [rowversion] NOT NULL
	END
END
GO



/*#end# upgrade statements from 5.1.3 to 6.0.0*/

/*#start# upgrade statements from 6.0.0 to 6.0.1*/
/*#end# upgrade statements from 6.0.0 to 6.0.1*/

/*#start# upgrade statements from 6.0.1 to 6.1.0*/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_HOST_BINARY_ASSOC]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	if not exists (select 1 from sys.syscolumns where name='INV_TIME' and id=object_id(N'[DBO].[SCOR_HOST_BINARY_ASSOC]'))
	BEGIN
		ALTER TABLE [dbo].[SCOR_HOST_BINARY_ASSOC] ADD INV_TIME [datetime] 
	END
END
GO


if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_BINARIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_BINARIES', 'BINARY_MD5') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_BINARIES] ADD BINARY_MD5 varchar(32)
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_OBSERVATIONS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_OBSERVATIONS', 'HOST_NAME') = 0))
BEGIN
	ALTER TABLE [dbo].[SCOR_OBSERVATIONS] ADD HOST_NAME nvarchar(256)
END 
GO

/*#end# upgrade statements from 6.0.1 to 6.1.0*/

/*#start# upgrade statements from 6.1.0 to 6.1.1*/

/* 
  Addition of new column DEFAULT_VALUE into SCOR_CONFIG - Moved at top along with SCOR_CONFIG table definition
  This is required to execute the 'insert into SCOR_CONFIG (...)' for STAGING tables creation.
*/

/*#end# upgrade statements from 6.1.0 to 6.1.1*/


/*#start# upgrade statements from 6.1.1 to 6.1.2*/

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_COMMON_BINARY_INFO') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_COMMON_BINARY_INFO', 'PUBLISHER_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_COMMON_BINARY_INFO] ADD [PUBLISHER_ID] int NULL
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'CHECKSUM') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD CHECKSUM nvarchar(40)
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'MODE') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD MODE tinyint NOT NULL DEFAULT 2 
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'GROUPED_REQ_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD GROUPED_REQ_ID int NULL
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'BINARY_PATH') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD BINARY_PATH  nvarchar(4000) NULL 
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'BINARY_BASE_NAME') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD BINARY_BASE_NAME nvarchar(256) NULL
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'IS_NETWORK_PATH') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD IS_NETWORK_PATH bit NOT NULL default 0
END 

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'IS_MP_VIOLATION') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD IS_MP_VIOLATION bit NOT NULL default 0
END 	

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_RULES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_RULES', 'CHECKSUM') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_RULES] ADD CHECKSUM varchar(40) NULL
END 

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_RULES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_RULES', 'GROUPED_REQ_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_RULES] ADD  GROUPED_REQ_ID int NULL
END 

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_RULES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_RULES', 'BINARY_BASE_NAME') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_RULES] ADD BINARY_BASE_NAME nvarchar(256) NULL
END 

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_RULES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_RULES', 'BINARY_PATH') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_RULES] ADD BINARY_PATH nvarchar(4000) NULL
END 

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_RULES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_RULES', 'BINARY_PATH_TRIMMED') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_RULES] ADD BINARY_PATH_TRIMMED nvarchar(4000) NULL
END 

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_RULES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_RULES', 'IS_NETWORK_PATH') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_RULES] ADD IS_NETWORK_PATH bit NOT NULL default 0
END 				
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_POLICY_GROUP') = 1) and (dbo.SCOR_CHECK_CONSTRAINT_EXISTS ('CK_VALIDATE_RULE_GROUP_NAME') = 0))
BEGIN
	alter table [dbo].[SCOR_POLICY_GROUP] add constraint CK_VALIDATE_RULE_GROUP_NAME CHECK (rtrim(ltrim(GROUP_NAME)) != 'My Rules' );
end
GO



/*#end# upgrade statements from 6.1.1 to 6.1.2*/

/*#start# upgrade statements from 6.1.3 to 6.1.7*/

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_BINARIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_BINARIES', 'BINARY_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_BINARIES] ADD [BINARY_SHA256] nvarchar(64)  NULL
END
GO
/*#end# upgrade statements from 6.1.3 to 6.1.7*/


/*#start# upgrade statements from 6.1.3 to 6.2.0*/
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_APPS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_APPS', 'HIDDEN') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_APPS] ADD [HIDDEN] bit NOT NULL DEFAULT 0
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_APPS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_APPS', 'APP_VERSION_CPE') = 0))
  BEGIN
    ALTER TABLE [dbo].[SCOR_INV_APPS] ADD [APP_VERSION_CPE] nvarchar(256) NULL
  END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_BINARIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_BINARIES', 'FIRST_SEEN_TIME') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_BINARIES] ADD FIRST_SEEN_TIME datetime NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_BINARIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_BINARIES', 'FIRST_SEEN_HOST') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_BINARIES] ADD [FIRST_SEEN_HOST] nvarchar(256) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_HOST_BINARY_ASSOC') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_HOST_BINARY_ASSOC', 'BINARY_ADDITION_TIME') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_HOST_BINARY_ASSOC] ADD BINARY_ADDITION_TIME datetime NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_DATA_CHANNEL') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_DATA_CHANNEL', 'COMPRESSED_DATA') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_DATA_CHANNEL] ADD [COMPRESSED_DATA] varbinary(max) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_DATA_CHANNEL') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_DATA_CHANNEL', 'COMPRESSION_TYPE') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_DATA_CHANNEL] ADD [COMPRESSION_TYPE] tinyint DEFAULT 0
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_DATA_CHANNEL') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_DATA_CHANNEL', 'COMPRESSION_ALGO') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_DATA_CHANNEL] ADD [COMPRESSION_ALGO] nvarchar(50) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'OBJECT_NAME') = 1)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ALTER COLUMN [OBJECT_NAME] nvarchar(4000) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_GROUPED_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_GROUPED_REQUEST', 'FILE_NAME') = 1)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_GROUPED_REQUEST] ALTER COLUMN [FILE_NAME] nvarchar(4000) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_GROUPED_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_GROUPED_REQUEST', 'USER_COMMENT') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_GROUPED_REQUEST] ADD [USER_COMMENT] nvarchar(4000) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_HOST_BINARY_ASSOC') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_HOST_BINARY_ASSOC', 'BINARY_PATH_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_HOST_BINARY_ASSOC] ADD [BINARY_PATH_ID] int NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_BINARIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_BINARIES', 'HIDDEN') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_BINARIES] ADD [HIDDEN] bit NOT NULL DEFAULT 0
END
GO



-- started deleting non-clustered indexes of SCOR_DATA_CHANNEL

dbo.SCOR_DROP_INDEX_PROC SCOR_DATA_CHANNEL, SCOR_DATA_CHANNEL_AGENTGUID;
GO

dbo.SCOR_DROP_INDEX_PROC SCOR_DATA_CHANNEL, SCOR_DATA_CHANNEL_TRANSACTION_ID;
GO

dbo.SCOR_DROP_INDEX_PROC SCOR_DATA_CHANNEL, SCOR_DATA_CHANNEL_TOTAL_CHUNKS;
GO

dbo.SCOR_DROP_INDEX_PROC SCOR_DATA_CHANNEL, SCOR_DATA_CHANNEL_DATA_TYPE;
GO

dbo.SCOR_DROP_INDEX_PROC SCOR_DATA_CHANNEL, SCOR_DATA_CHANNEL_RECEIVEDUTC;
GO

dbo.SCOR_DROP_INDEX_PROC SCOR_DATA_CHANNEL, SCOR_DATA_CHANNEL_ANCHORED;
GO

dbo.SCOR_DROP_INDEX_PROC SCOR_DATA_CHANNEL, SCOR_DATA_CHANNEL_DETECTED_UTC;
GO

-- finished deleting non-clustered indexes of SCOR_DATA_CHANNEL

dbo.SCOR_DROP_NOT_NAMED_CONSTRAINT 'SCOR_HOST_BINARY_ASSOC' ,'BINARY_ID','FOREIGN KEY' ;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_CLEANUP_SCOR_COMMON_BINARY_INFO;
GO
/*#end# upgrade statements from 6.1.3 to 6.2.0*/

/*#start# upgrade statements from 6.2.0 to 7.0.0*/
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_COMMON_BINARY_INFO') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_COMMON_BINARY_INFO', 'BINARY_REPUTATION_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_COMMON_BINARY_INFO] ADD [BINARY_REPUTATION_ID] int NULL;
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_GROUPED_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_GROUPED_REQUEST', 'BINARY_REPUTATION_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_GROUPED_REQUEST] ADD [BINARY_REPUTATION_ID] int NULL;
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_BINARIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_BINARIES', 'BINARY_REPUTATION_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_BINARIES] ADD [BINARY_REPUTATION_ID] int NULL;
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_APPS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_APPS', 'IS_REPUTATION_SYNCED') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_APPS] ADD [IS_REPUTATION_SYNCED] bit NOT NULL DEFAULT 0
END
GO


if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_FILE_SHA1') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_FILE_SHA1] varchar(40) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_FILE_MD5') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_FILE_MD5] varchar(32) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_FILE_TYPE') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_FILE_TYPE] varchar(30) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_PROCESS_SHA1') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_PROCESS_SHA1] varchar(40) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_PROCESS_MD5') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_PROCESS_MD5] varchar(32) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_DENY_REASON_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_DENY_REASON_ID] int NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_REPUTATION_SCORE') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_REPUTATION_SCORE] int NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_DENY_REASON') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_DENY_REASON] nvarchar(4000) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'USER_COMMENT') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [USER_COMMENT] nvarchar(4000) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_COMMON_BINARY_INFO') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_COMMON_BINARY_INFO', 'CERTIFICATE_STATUS') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_COMMON_BINARY_INFO] ADD [CERTIFICATE_STATUS] tinyint NOT NULL default 1
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_FD_FILE_INFO') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_FD_FILE_INFO', 'LAST_MODIFIED_TIME') = 0)) 
BEGIN
ALTER TABLE [dbo].[SCOR_FD_FILE_INFO] ADD [LAST_MODIFIED_TIME] datetime
END
GO

dbo.SCOR_DROP_TABLE SCOR_HIPS_BINARY_IP_ASSOC;
GO
dbo.SCOR_DROP_TABLE SCOR_HIPS_IP_ADDRESS;
GO
dbo.SCOR_DROP_TABLE SCOR_HIPS_BINARY;
GO
/*#end# upgrade statements from 6.2.0 to 7.0.0*/

/*#start# upgrade statements from 7.0.0 to 7.0.1 */

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'AutoGUID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD AutoGUID uniqueidentifier
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) AND (dbo.SCOR_CHECK_COLUMN_EXISTS ('SCOR_ROLLUP_EVENTS', 'EPO_EVENT_AUTO_ID' ) = 0))
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EPO_EVENT_AUTO_ID int NULL;
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_FILE_SHA1') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_FILE_SHA1 varchar(40)
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_FILE_MD5') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_FILE_MD5 varchar(32)
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_FILE_TYPE') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_FILE_TYPE varchar(30)
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_PROCESS_SHA1') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_PROCESS_SHA1 varchar(40)
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_PROCESS_MD5') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_PROCESS_MD5 varchar(32)
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_DENY_REASON_ID') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_DENY_REASON_ID int null
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_DENY_REASON') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_DENY_REASON nvarchar(4000)
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_REPUTATION_SCORE') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_REPUTATION_SCORE int null
END
GO


/*#end# upgrade statements from 7.0.0 to 7.0.1*/

/*#start# upgrade statements from 7.0.1 to 8.0.0 */
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_SYSTEM_PROPERTIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_SYSTEM_PROPERTIES', 'INVENTORY_FETCH_STATUS') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_SYSTEM_PROPERTIES] ADD INVENTORY_FETCH_STATUS  tinyint NOT NULL DEFAULT 0
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_INV_SYSTEM_PROPERTIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_INV_SYSTEM_PROPERTIES', 'JVM_MEMORY_REQUIRED') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_INV_SYSTEM_PROPERTIES] ADD JVM_MEMORY_REQUIRED  tinyint NOT NULL DEFAULT 0
END
GO


if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_FILE_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_FILE_SHA256] varchar(64) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_PROCESS_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ADD [EVT_PROCESS_SHA256] varchar(64) NULL
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_FILE_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_FILE_SHA256 varchar(64)
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_PROCESS_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ADD EVT_PROCESS_SHA256 varchar(64)
END
GO

/*#end# upgrade statements from 7.0.1 to 8.0.0 */

/*For Solidifier Properties*/
if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CUSTOM_PRODUCT_PROPERTIES]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SCOR_CUSTOM_PRODUCT_PROPERTIES]
(
	[AutoID]					[int] NOT NULL IDENTITY(1,1),
	[ParentID]					[int] NOT NULL,				-- Required for custom properties FK to ProductProps
	[ss_status]					nvarchar(64),
	[ss_status_on_reboot] 		nvarchar(64),
	[cli_access]				nvarchar(64),
	[act_status]				nvarchar(64),
	[mp_status]					nvarchar(64),
	[DEP]						nvarchar(64),
	[ASLR]						nvarchar(64),
	[szProductVer]				nvarchar(64),
	[service_status]			nvarchar(64),
	[build_status]				nvarchar(64),
	[build_validation_status]	nvarchar(64),
	[reboot_required_for_uninstall] nvarchar(64),
	[isATDSubmissionAllowed]	nvarchar(64),
	[upgrade_status]            nvarchar(64),
	[initial_scan_status]		nvarchar(64),
	[license_change_control]	nvarchar(64),
	[license_runtime_control]	nvarchar(64),
	[self-approval]				nvarchar(64),
	[mp-vasr]					nvarchar(64),
	[mp-nx]						nvarchar(64),
	[mp-casp]					nvarchar(64),
	[ob-logging]				nvarchar(64),
	[execution-control]			nvarchar(64),
	[pkg-ctrl]				    nvarchar(64),
	[activex]					nvarchar(64),
	[tie-reputation]			nvarchar(64),
	[gti-reputation]			nvarchar(64),
	[sau]						nvarchar(64),
	[so_status]					nvarchar(64),
	[throttling_events_cache_full_percentage]	nvarchar(64),
	[throttling_events_dropped]					nvarchar(64),  
	[throttling_events_threshold_hit_time]		nvarchar(64),
	[pull_inv_last_access_time]					nvarchar(64),
	[pull_inv_next_allowed_time]				nvarchar(64),
	[throttling_invdiff_threshold_hit_time]		nvarchar(64),
	[throttling_ob_cache_full_percentage]		nvarchar(64),
	[throttling_ob_dropped]						nvarchar(64),
	[throttling_ob_threshold_hit_time]			nvarchar(64),
	
	CONSTRAINT [PK_SCOR_CUSTOM_PRODUCT_PROPERTIES] PRIMARY KEY CLUSTERED (
		[AutoID] ASC
	) ON [PRIMARY]
) ON [PRIMARY]

ALTER TABLE [dbo].[SCOR_CUSTOM_PRODUCT_PROPERTIES] ADD
	CONSTRAINT [FK_SCOR_CUSTOM_PRODUCT_PROPERTIES_EPOProductProperties] FOREIGN KEY ([ParentID]) REFERENCES [dbo].[EPOProductProperties] ([AutoID]) 
	ON DELETE CASCADE ON UPDATE NO ACTION
	
create index SCOR_IDX_SCOR_CUSTOM_PRODUCT_PROPERTIES on [dbo].[SCOR_CUSTOM_PRODUCT_PROPERTIES] (ParentID);	
END	
GO


/*#start# upgrade statements from 7.0.1 to 8.0.0 */
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_COMMON_BINARY_INFO') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_COMMON_BINARY_INFO', 'BINARY_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_COMMON_BINARY_INFO] ADD [BINARY_SHA256] varchar(64) NULL;
	CREATE INDEX [SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA256] ON [dbo].[SCOR_COMMON_BINARY_INFO] ([BINARY_SHA256]);
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_REQUEST', 'BINARY_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_REQUEST] ADD [BINARY_SHA256] varchar(64) NULL
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_GROUPED_REQUEST') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_GROUPED_REQUEST', 'BINARY_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_GROUPED_REQUEST] ADD [BINARY_SHA256] varchar(64) NULL;
	 CREATE INDEX [SCOR_SA_GROUPED_REQUEST_BINARY_SHA256] ON [dbo].[SCOR_SA_GROUPED_REQUEST] ([BINARY_SHA256] ASC) include (IS_MP_VIOLATION);
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_SA_RULES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_SA_RULES', 'BINARY_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_SA_RULES] ADD [BINARY_SHA256] varchar(64) NULL;
	DROP INDEX [dbo].[SCOR_SA_RULES].[SCOR_SA_RULE_GROUPED_REQ_ID];
	CREATE INDEX [SCOR_SA_RULE_GROUPED_REQ_ID] ON [dbo].[SCOR_SA_RULES] ([GROUPED_REQ_ID] ASC)
INCLUDE ( [AUTO_ID],[EVENT_TYPE],[SA_ACTION],[CHECKSUM],[BINARY_INFO_ID],[BINARY_PATH],[IS_NETWORK_PATH],[BINARY_SHA256]) ;
END 
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_APPLICATIONS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_APPLICATIONS', 'BINARY_SHA256') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_APPLICATIONS] ADD [BINARY_SHA256] nvarchar(64) NULL;
END
GO

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_CUSTOM_PRODUCT_PROPERTIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_CUSTOM_PRODUCT_PROPERTIES', 'execution-control') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_CUSTOM_PRODUCT_PROPERTIES] ADD [execution-control]	nvarchar(64) NULL;
END

if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_CUSTOM_PRODUCT_PROPERTIES') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_CUSTOM_PRODUCT_PROPERTIES', 'sau') = 0)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_CUSTOM_PRODUCT_PROPERTIES] ADD [sau] nvarchar(64) NULL;
END


GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_CMD_LINE') = 1)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ALTER COLUMN [EVT_CMD_LINE]	nvarchar(4000) NULL;
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_CMD_LINE') = 1)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ALTER COLUMN [EVT_CMD_LINE]	nvarchar(4000) NULL;
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_EVENTS', 'EVT_COMMENT') = 1)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_EVENTS] ALTER COLUMN [EVT_COMMENT]	nvarchar(4000) NULL;
END
GO
if ((dbo.SCOR_CHECK_TABLE_EXISTS ('SCOR_ROLLUP_EVENTS') = 1) and (dbo.SCOR_CHECK_COLUMN_EXISTS('SCOR_ROLLUP_EVENTS', 'EVT_COMMENT') = 1)) 
BEGIN
	ALTER TABLE [dbo].[SCOR_ROLLUP_EVENTS] ALTER COLUMN [EVT_COMMENT]	nvarchar(4000) NULL;
END
GO




if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_PD_FILTER_INFO]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		create TABLE [dbo].[SCOR_PD_FILTER_INFO](
			[AUTO_ID] [int] IDENTITY(1,1) NOT NULL,
			[GROUP] [nvarchar](256) NULL,
			[IP_ADDRESS_V4] int NULL,
			[IP_ADDRESS_V6] binary(16) NULL,
			[LAST_COMMUNICATION]  [datetime] NULL,
			[MANAGED_STATE] [nvarchar](256) NULL,
			[OS_PLATFORM] [nvarchar](256) NULL,
			[OS_TYPE] [nvarchar](256) NULL,
			[OS_VERSION] [nvarchar](256) NULL,
			[TAGS] [nvarchar](256) NULL,
			[USER_NAME] [nvarchar](256) NOT NULL,
			PRIMARY KEY (     [AUTO_ID] ASC)
		)
	END
GO






if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_IMPORT_HISTORY]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		CREATE TABLE [dbo].[SCOR_IMPORT_HISTORY](
			[id] [int] IDENTITY(1,1) NOT NULL,
			[DateStart] [datetime] NOT NULL,
			[DateEnd] [datetime] NULL,
			[ImportType] [smallint] NOT NULL,
			[Status] [smallint] NOT NULL,
			[UserId] [int] NOT NULL,
			[lastUpdate] [datetime] NULL,
			CONSTRAINT [PK_SCOR_IMPORT_HISTORY] PRIMARY KEY CLUSTERED
				(
					[id] ASC
				)
		)
	END
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_IMPORT_DETAILS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		CREATE TABLE [dbo].[SCOR_IMPORT_DETAILS](
			[id] [int] IDENTITY(1,1) NOT NULL,
			[import_id] [int] NOT NULL,
			[cpeFilename] [nvarchar](500) NOT NULL,
			[cpeProductName] [nvarchar](100) NOT NULL,
			[cpeSchemaVersion] [nvarchar](10) NOT NULL,
			[cpeProductVersion] [nvarchar](10) NOT NULL,
			[cpeCount] [int] NULL,
			[cpeTimeStamp] [datetime] NOT NULL,
			CONSTRAINT [PK_SCOR_IMPORT_DETAILS] PRIMARY KEY CLUSTERED
				(          [id] ASC        )
		)


		ALTER TABLE [dbo].[SCOR_IMPORT_DETAILS]  WITH CHECK ADD  CONSTRAINT [FK_SCOR_IMPORT_DETAILS_SCOR_IMPORT_HISTORY] FOREIGN KEY([import_id])
		REFERENCES [dbo].[SCOR_IMPORT_HISTORY] ([id])
		ALTER TABLE [dbo].[SCOR_IMPORT_DETAILS] CHECK CONSTRAINT [FK_SCOR_IMPORT_DETAILS_SCOR_IMPORT_HISTORY]
		ALTER TABLE [dbo].[SCOR_IMPORT_DETAILS] ADD  CONSTRAINT [DF_SCOR_IMPORT_DETAILS_CPETIMESTAMP]  DEFAULT (getutcdate()) FOR [cpeTimeStamp]

	END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CPE_NAMES]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		CREATE TABLE [dbo].[SCOR_CPE_NAMES](
			[id] [int] IDENTITY(1,1) NOT NULL,
			[Name] [nvarchar](250) NOT NULL,
			[import_details_id] [int] NOT NULL,
			[Deprecated] [bit] NOT NULL,
			[DeprecatedBy] [nvarchar](250) NULL,
			[DeprecationDate] [datetime] NULL,
			[cpe23Name] [nvarchar](250) NULL,
			[cpe23DeprecationDate] [datetime] NULL,
			[cpe23DeprecatedByName] [nvarchar](250) NULL,
			[cpe23DeprecatedType] [nvarchar](250) NULL,
			[cpeAttributePart] [nvarchar](1) NULL,
			[cpeAttributeVendor] [nvarchar](250) NULL,
			[cpeAttributeProduct] [nvarchar](250) NULL,
			[cpeAttributeVersion] [nvarchar](250) NULL,
			CONSTRAINT [PK_scor_cpe_names] PRIMARY KEY CLUSTERED
				(		[id] ASC	))
		ALTER TABLE [dbo].[SCOR_CPE_NAMES]  WITH CHECK ADD  CONSTRAINT [FK_scor_cpe_names_scor_import_details] FOREIGN KEY([import_details_id])
		REFERENCES [dbo].[SCOR_IMPORT_DETAILS] ([id])
		ALTER TABLE [dbo].[SCOR_CPE_NAMES] CHECK CONSTRAINT [FK_scor_cpe_names_scor_import_details]
	END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CPE_NAME_REFERENCE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		CREATE TABLE [dbo].[SCOR_CPE_NAME_REFERENCE](
			[id] [bigint] IDENTITY(1,1) NOT NULL,
			[cpe_name_id] [int] NOT NULL,
			[name] [nvarchar](256) NOT NULL,
			[referencelink] [nvarchar](512) NOT NULL,
			CONSTRAINT [PK_scor_cpe_name_reference] PRIMARY KEY CLUSTERED
				([id] ASC))
		ALTER TABLE [dbo].[SCOR_CPE_NAME_REFERENCE]  WITH CHECK ADD  CONSTRAINT [FK_scor_cpe_name_reference_scor_cpe_names] FOREIGN KEY([cpe_name_id])
		REFERENCES [dbo].[SCOR_CPE_NAMES] ([id])
			ON UPDATE CASCADE
			ON DELETE CASCADE

		ALTER TABLE [dbo].[SCOR_CPE_NAME_REFERENCE] CHECK CONSTRAINT [FK_scor_cpe_name_reference_scor_cpe_names]
	END
GO
if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CPE_NAME_NOTE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		CREATE TABLE [dbo].[SCOR_CPE_NAME_NOTE](
			[id] [bigint] IDENTITY(1,1) NOT NULL,
			[cpe_name_id] [int] NOT NULL,
			[note] [nvarchar](512) NOT NULL,
			[language] [nvarchar](6) NOT NULL,
			CONSTRAINT [PK_scor_cpe_name_note] PRIMARY KEY CLUSTERED
				([id] ASC))

		ALTER TABLE [dbo].[SCOR_CPE_NAME_NOTE]  WITH CHECK ADD  CONSTRAINT [FK_scor_cpe_name_note_scor_cpe_name_note] FOREIGN KEY([cpe_name_id])
		REFERENCES [dbo].[SCOR_CPE_NAMES] ([id])
			ON UPDATE CASCADE
			ON DELETE CASCADE
		ALTER TABLE [dbo].[SCOR_CPE_NAME_NOTE] CHECK CONSTRAINT [FK_scor_cpe_name_note_scor_cpe_name_note]
	END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CPE_NAME_TITLE]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		CREATE TABLE [dbo].[SCOR_CPE_NAME_TITLE](
			[id] [bigint] IDENTITY(1,1) NOT NULL,
			[cpe_name_id] [int] NOT NULL,
			[title] [nvarchar](256) NOT NULL,
			[language] [nvarchar](6) NOT NULL,
			CONSTRAINT [PK_scor_cpe_name_titles] PRIMARY KEY CLUSTERED
				([id] ASC))
		ALTER TABLE [dbo].[SCOR_CPE_NAME_TITLE]  WITH CHECK ADD  CONSTRAINT [FK_scor_cpe_name_titles_scor_cpe_names] FOREIGN KEY([cpe_name_id])
		REFERENCES [dbo].[SCOR_CPE_NAMES] ([id])
			ON UPDATE CASCADE
			ON DELETE CASCADE
		ALTER TABLE [dbo].[SCOR_CPE_NAME_TITLE] CHECK CONSTRAINT [FK_scor_cpe_name_titles_scor_cpe_names]
	END
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CPE_NAME_CHECK]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		CREATE TABLE [dbo].[SCOR_CPE_NAME_CHECK](
			[id] [bigint] IDENTITY(1,1) NOT NULL,
			[cpe_name_id] [int] NOT NULL,
			[system] [nvarchar](500) NOT NULL,
			[href] [nvarchar](500) NOT NULL,
			[checkName] [nvarchar](256) NOT NULL,
			CONSTRAINT [PK_scor_cpe_name_check] PRIMARY KEY CLUSTERED
				(
					[id] ASC
				)
		)
		ALTER TABLE [dbo].[SCOR_CPE_NAME_CHECK]  WITH CHECK ADD  CONSTRAINT [FK_scor_cpe_name_check_scor_cpe_name_check] FOREIGN KEY([cpe_name_id])
		REFERENCES [dbo].[SCOR_CPE_NAMES] ([id])
			ON UPDATE CASCADE
			ON DELETE CASCADE
		ALTER TABLE [dbo].[SCOR_CPE_NAME_CHECK] CHECK CONSTRAINT [FK_scor_cpe_name_check_scor_cpe_name_check]
	END
GO





if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_CPE_APPS]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	BEGIN
		CREATE TABLE [dbo].[SCOR_CPE_APPS](
			[AUTO_ID] int IDENTITY(1,1) NOT NULL,
			[CPE_ID] int NULL,
			[APP_ID] int  NOT NULL,
			[APP_NAME] nvarchar(256) NOT NULL,
			[APP_VERSION] nvarchar(64)NOT NULL,
			[APP_VENDOR] nvarchar(256) NOT NULL,
			[APP_DISP_NAME] nvarchar(256) NOT NULL,
			[APP_DISP_VERSION] nvarchar(64) NULL,
			[APP_DISP_VENDOR] nvarchar(256) NULL,
			[CPE_NAME] nvarchar(400) NOT NULL,
			[FOUND_METHOD] int NOT NULL,
			primary key (AUTO_ID)
		)
		alter table [dbo].[SCOR_CPE_APPS] add constraint SCOR_UNIQUE_CPE_APPS UNIQUE  (APP_ID,CPE_NAME,FOUND_METHOD);
	END
GO

/*to drop a legacy view in 6.2.0 while upgrade*/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_VW_PROPERTIES]') and OBJECTPROPERTY(id, N'IsView') = 1)
BEGIN
    DROP VIEW SCOR_VW_PROPERTIES
END
GO

/* dropping old index and creating new one during upgrade to 8.3.3*/
if exists (select * from sys.indexes where name = 'SCOR_FD_DATACHANNEL_DETECTED_UTC' and object_id = object_id('[SCOR_FD_DATA_CHANNEL]'))
BEGIN
    DROP INDEX SCOR_FD_DATACHANNEL_DETECTED_UTC on SCOR_FD_DATA_CHANNEL
    CREATE NONCLUSTERED INDEX [SCOR_FD_DATACHANNEL_COV_AG_DU_SN_TI] ON [dbo].[SCOR_FD_DATA_CHANNEL] ([AGENTGUID], [DETECTED_UTC], [SEQ_NO], [TRANSACTION_ID])
END
GO