/* Copyright (C) 2018 McAfee, Inc.  All rights reserved.*/
/*
uninstall.xml is executed when this extension is uninstalled from EPO and also before installing this extension in EPO.
*/
/* The database object (table,view,procedure,function,trigger etc.) to be dropped should be passed to its corresponding procedure for dropping.
   This is done so as to make the sqls reentrant.
*/
/* The drop procedures are created and then altered so that this is the final definition of the procedure, even if it existed before/was changed.
This is done to ensure the correctness of the procedure.
*/

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_PROCEDURE]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
EXEC ('CREATE PROCEDURE dbo.SCOR_DROP_PROCEDURE AS SELECT 1')
GO

ALTER PROCEDURE dbo.SCOR_DROP_PROCEDURE
	@procName nvarchar(128)
AS
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @procName + ''') and OBJECTPROPERTY(id, N''IsProcedure'') = 1)
			drop procedure dbo.'+ @procName;

	EXEC (@Stmt)
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_TABLE]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
EXEC ('CREATE PROCEDURE dbo.SCOR_DROP_TABLE AS SELECT 1')
GO

ALTER PROCEDURE dbo.SCOR_DROP_TABLE
	@tableName nvarchar(128)
AS
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @tableName + ''') and OBJECTPROPERTY(id, N''IsUserTable'') = 1)
			drop table dbo.'+ @tableName;

	EXEC (@Stmt)
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_VIEW]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
EXEC ('CREATE PROCEDURE dbo.SCOR_DROP_VIEW AS SELECT 1')
GO

ALTER PROCEDURE dbo.SCOR_DROP_VIEW
	@viewName nvarchar(128)
AS
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @viewName + ''') and OBJECTPROPERTY(id, N''IsView'') = 1)
			drop view dbo.'+ @viewName;

	EXEC (@Stmt)
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_FUNCTION]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
EXEC ('CREATE PROCEDURE dbo.SCOR_DROP_FUNCTION AS SELECT 1')
GO

ALTER PROCEDURE dbo.SCOR_DROP_FUNCTION
	@funcName nvarchar(128)
AS
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @funcName + ''') and  xtype in (N''FN'', N''IF'', N''TF''))
			drop function dbo.'+ @funcName;

	EXEC (@Stmt)
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_TRIGGER]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
EXEC ('CREATE PROCEDURE dbo.SCOR_DROP_TRIGGER AS SELECT 1')
GO

ALTER PROCEDURE dbo.SCOR_DROP_TRIGGER
	@triggerName nvarchar(256)
AS
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @triggerName + ''') and OBJECTPROPERTY(id, N''IsTrigger'') = 1)
			drop trigger dbo.'+ @triggerName;

	EXEC (@Stmt)
END
GO

dbo.SCOR_DROP_FUNCTION SCOR_FN_IS_PARTITIONING_SUPPORTED;
GO

CREATE FUNCTION dbo.SCOR_FN_IS_PARTITIONING_SUPPORTED()
RETURNS bit as
BEGIN

	DECLARE @RET bit;
	SET @RET = 0;	

	DECLARE @editionId int;
	
	DECLARE @enterpriseEditionId int;
	SET @enterpriseEditionId = 1804890536;

	DECLARE @developerEditionId int;
	SET @developerEditionId = -2117995310;

	DECLARE @enterpriseEvaluationId int;
	SET @enterpriseEvaluationId = -610778273;

	SELECT @editionId = cast(SERVERPROPERTY('EditionId') as int);

	IF ((@editionId = @enterpriseEditionId) or (@editionId = @developerEditionId) or (@editionId = @enterpriseEvaluationId)) 
		BEGIN
			SET @RET = 1;
		END;
	RETURN @RET;
END;
GO


if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_PARTITION_FUNCTION]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
EXEC ('CREATE PROCEDURE dbo.SCOR_DROP_PARTITION_FUNCTION AS SELECT 1')
GO
ALTER PROCEDURE dbo.SCOR_DROP_PARTITION_FUNCTION
	@funcName nvarchar(128)
AS 
BEGIN
	if (dbo.SCOR_FN_IS_PARTITIONING_SUPPORTED() = 1)
	BEGIN
		DECLARE @Stmt nvarchar (2048)
		SET @Stmt = 'if exists (select 1 from sys.partition_functions where name= '''
			+ @funcName + ''')
				drop PARTITION FUNCTION '+ @funcName;
		
		EXEC (@Stmt)
	END
END
GO

if not exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_PARTITION_SCHEME]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
EXEC ('CREATE PROCEDURE dbo.SCOR_DROP_PARTITION_SCHEME AS SELECT 1')
GO

ALTER PROCEDURE dbo.SCOR_DROP_PARTITION_SCHEME
	@funcName nvarchar(128)
AS 
BEGIN
	if (dbo.SCOR_FN_IS_PARTITIONING_SUPPORTED() = 1)
	BEGIN
		DECLARE @Stmt nvarchar (2048)
		SET @Stmt = 'if exists (select 1 from sys.partition_schemes where name = '''
			+ @funcName + ''')
				drop PARTITION SCHEME '+ @funcName;
		
		EXEC (@Stmt)
	END
END
GO

/*
 * It is necessary to drop this view before some tables because it is an indexed view */
dbo.SCOR_DROP_VIEW SCOR_VW_HOST_BINARY_ASSOC_WITH_PATH;
GO

dbo.SCOR_DROP_TABLE SCOR_IMAGE_DEVIATION_HISTORY_DETAILS;
GO
dbo.SCOR_DROP_TABLE SCOR_IMAGE_DEVIATION_HISTORY;
GO
dbo.SCOR_DROP_TABLE SCOR_TASK_CLEANUP_REGISTRY;
GO
dbo.SCOR_DROP_TABLE SCOR_HOST_BINARY_ASSOC;
GO

dbo.SCOR_DROP_TABLE SCOR_STAGING_HOST_BINARY_ASSOC;
GO
dbo.SCOR_DROP_PARTITION_SCHEME SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_SCHEME;
GO
dbo.SCOR_DROP_PARTITION_FUNCTION SCOR_STAGING_HOST_BINARY_ASSOC_PARTITION_FN;
GO
dbo.SCOR_DROP_TABLE SCOR_STAGING_HOST_BINARY_ASSOC_MAPPING;
GO

dbo.SCOR_DROP_TABLE SCOR_INV_BINARIES;
GO
dbo.SCOR_DROP_TABLE SCOR_INV_APPS;
GO
dbo.SCOR_DROP_TABLE SCOR_INV_SYSTEM_PROPERTIES;
GO
dbo.SCOR_DROP_TABLE SCOR_INV_SAVED_SEARCHES;
GO
dbo.SCOR_DROP_TABLE SCOR_EVENTS;
GO
dbo.SCOR_DROP_TABLE SCOR_EVENT_DATA_FIELD_MAPPING;
GO
dbo.SCOR_DROP_TABLE SCOR_EVENT_INFO;
GO
dbo.SCOR_DROP_TABLE SCOR_CONFIG;
GO

dbo.SCOR_DROP_TABLE SCOR_RECON_CYCLE_HISTORY;
GO
dbo.SCOR_DROP_TABLE SCOR_RECON_HOST_DETAIL_RESULT;
GO
dbo.SCOR_DROP_TABLE SCOR_RECON_ACTIONS_FOR_AS;
GO

dbo.SCOR_DROP_TABLE SCOR_RECON_TICKET_PROPERTIES;
GO
dbo.SCOR_DROP_TABLE SCOR_RECON_TICKET;
GO
dbo.SCOR_DROP_TABLE SCOR_RECON_TICKET2;
GO

dbo.SCOR_DROP_TABLE SCOR_RECON_CYCLE_LOG;
GO
dbo.SCOR_DROP_TABLE SCOR_RECON_SUMMARY;
GO

dbo.SCOR_DROP_TABLE SCOR_ENFORCEMENT_TICKET_SYSTEM_ASSOC;
GO
dbo.SCOR_DROP_TABLE SCOR_ENFORCEMENT_TICKET;
GO

dbo.SCOR_DROP_TABLE SCOR_DATA_CHANNEL;
GO
dbo.SCOR_DROP_TABLE SCOR_STAGING_DATA_CHANNEL;
GO
dbo.SCOR_DROP_PARTITION_SCHEME SCOR_STAGING_DATA_CHANNEL_PARTITION_SCHEME;
GO
dbo.SCOR_DROP_PARTITION_FUNCTION SCOR_STAGING_DATA_CHANNEL_PARTITION_FN;
GO

dbo.SCOR_DROP_TABLE SCOR_STAGING_DATA_CHANNEL_MAPPING;
GO

dbo.SCOR_DROP_TABLE SCOR_COMMAND_RESPONSE;
GO
dbo.SCOR_DROP_TABLE SCOR_ALERTS;
GO
dbo.SCOR_DROP_TABLE SCOR_DATA_CHANNEL;
GO
dbo.SCOR_DROP_TABLE SCOR_PUBLISHERS;
GO
dbo.SCOR_DROP_TABLE SCOR_APPLICATIONS;
GO
dbo.SCOR_DROP_TABLE SCOR_POLICY_GROUP_USER_ASSOC;
GO
dbo.SCOR_DROP_TABLE SCOR_POLICY_GROUP_RULES;
GO
dbo.SCOR_DROP_TABLE SCOR_POLICY_GROUP;
GO
dbo.SCOR_DROP_TABLE SCOR_DIAG;
GO
dbo.SCOR_DROP_TABLE SCOR_ROLLUP_EVENTS;
GO
dbo.SCOR_DROP_TABLE SCOR_OBSERVATIONS;
GO
dbo.SCOR_DROP_TABLE SCOR_OBSERVATION_FILTERS;
GO
dbo.SCOR_DROP_TABLE SCOR_OBSERVATION_STATISTICS;
GO
dbo.SCOR_DROP_TABLE SCOR_FD_DATA_CHANNEL;
GO
dbo.SCOR_DROP_TABLE SCOR_FD_FILE_REPOS;
GO
dbo.SCOR_DROP_TABLE SCOR_FD_FILE_INFO;
GO
dbo.SCOR_DROP_TABLE SCOR_NORM_VENDORS;
GO
dbo.SCOR_DROP_TABLE SCOR_SA_RULES;
GO
dbo.SCOR_DROP_TABLE SCOR_SA_REQUEST;
GO
dbo.SCOR_DROP_TABLE SCOR_SA_GROUPED_REQUEST;
GO
dbo.SCOR_DROP_TABLE SCOR_COMMON_BINARY_INFO;
GO
dbo.SCOR_DROP_TABLE SCOR_BINARY_PATHS;
GO
dbo.SCOR_DROP_TABLE SCOR_ASYNC_JOB;
GO
dbo.SCOR_DROP_TABLE SCOR_BINARY_REPUTATION_CERT_ASSOC;
GO
dbo.SCOR_DROP_TABLE SCOR_CERT_REPUTATION;
GO
dbo.SCOR_DROP_TABLE SCOR_BINARY_REPUTATION;
GO
dbo.SCOR_DROP_TABLE SCOR_CERTIFICATE;
GO
dbo.SCOR_DROP_TABLE SCOR_CUSTOM_PRODUCT_PROPERTIES;
GO
dbo.SCOR_DROP_TABLE SCOR_PD_FILTER_INFO;
GO
dbo.SCOR_DROP_TABLE SCOR_CPE_NAME_CHECK;
GO
dbo.SCOR_DROP_TABLE SCOR_CPE_NAME_TITLE;
GO
dbo.SCOR_DROP_TABLE SCOR_CPE_NAME_NOTE;
GO
dbo.SCOR_DROP_TABLE SCOR_CPE_NAME_REFERENCE;
GO
dbo.SCOR_DROP_TABLE SCOR_CPE_APPS
GO
if  exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[FK_SCOR_CPE_APPS_SCOR_CPE_NAMES]') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
	BEGIN
		ALTER TABLE [dbo].[SCOR_CPE_APPS] DROP CONSTRAINT [FK_SCOR_CPE_APPS_SCOR_CPE_NAMES]
	END
GO
if exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[FK_scor_cpe_names_scor_import_details]') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
	BEGIN
		ALTER TABLE [dbo].[SCOR_CPE_NAMES] DROP CONSTRAINT [FK_scor_cpe_names_scor_import_details]
	END
GO
if exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[FK_scor_import_details_scor_import_history]') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
	BEGIN
		ALTER TABLE [dbo].[SCOR_IMPORT_DETAILS] DROP CONSTRAINT [FK_scor_import_details_scor_import_history]
	END
GO

dbo.SCOR_DROP_TABLE SCOR_CPE_APPS;
GO
dbo.SCOR_DROP_TABLE SCOR_CPE_NAMES;
GO
dbo.SCOR_DROP_TABLE SCOR_IMPORT_DETAILS;
GO
dbo.SCOR_DROP_TABLE SCOR_IMPORT_HISTORY;
GO


dbo.SCOR_DROP_PROCEDURE SCOR_EVENT_INSERT;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_PUBLISHERS_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_EVENT_DATA_FIELD_MAPPING_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_EVENT_INFO_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_CONFIG_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_CONFIG_PROC_UPDATE;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_CONFIG_PROC_LICENSE;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_CREATE_INDEX_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_DROP_INDEX_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_ADD_UNIQUE_CONSTRAINT_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_DROP_UNIQUE_CONSTRAINT_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_INSERT_VENDOR;
GO


dbo.SCOR_DROP_FUNCTION ScorGetEPOBranchNodes;
GO
dbo.SCOR_DROP_FUNCTION ScorSplit;
GO
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_TABLE_EXISTS;
GO
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_TEMP_TABLE_EXISTS;
GO
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_COLUMN_EXISTS;
GO
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_INDEX_EXISTS;
GO
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_INDEX_EXISTS_IN_TABLE;
GO
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_IS_NULL;
GO
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_TRIGGER_EXISTS;
GO
dbo.SCOR_DROP_FUNCTION SCOR_GENERATE_DATE_RANGE;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_PROPERTIES;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_LICENSE;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_STATUS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CHANGES_IN_MANIFEST;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CHANGES_NOT_IN_MANIFEST;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CHANGES_NOT_IMPLEMENTED;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CHANGE_MANAGEMENT_COMPLIANCE;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_POLICIES_ON_HOSTS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_NON_COMPLIANT_AGENT;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_INVENTORY;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_INVENTORY_AGE;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_POLICIES_WITH_RULES;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_IMAGE_DEVIATION_HISTORY_DETAILS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_MANIFEST_CHANGES_METHOD1_VIEW;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_MANIFEST_CHANGES_METHOD2_VIEW;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_ENFORCEMENT_TICKET;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_POLICIES_WITH_RULES;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_OBSERVATION;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_BINARY_HOST_STATS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_EVENT_FEEDBACK_DATA;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_INV_APPS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_INV_BINARIES;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_HOST_BINARY_ASSOC;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_BINARY_AVAILABILITY_BY_TYPE;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_APP_AVAILABILITY;
GO
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_CONSTRAINT_EXISTS;
GO
dbo.SCOR_DROP_FUNCTION SCOR_FN_IS_PARTITIONING_SUPPORTED;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_RECON_CONFIG_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_INV_SAVED_SEARCHES_PROC;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_INSERT_RULE_GROUP;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_INSERT_SCOR_APPLICATIONS ;
GO
dbo.SCOR_DROP_VIEW SCOR_FEATURES_STATUS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_THROTTLING_STATUS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_SELF_APPROVAL_AUDIT_REPORT;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_SA_GROUPED_REQUEST;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_DATA_CONJESTION_STATUS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_SCOR_SA_REQUEST;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_SA_REQUEST;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_PD_INFO_FILTER;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CPE_LATEST_NAMES_AVAILABLE;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CPE_CURRENT_APPLICATIONS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CPE_INVENTORY_APPS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CPE_SYSTEMS;
GO
dbo.SCOR_DROP_VIEW SCOR_VW_CPE_APPS_SYSTEM;
GO

dbo.SCOR_DROP_TRIGGER TR_SCOR_SA_REQUEST_INSERT;
GO
dbo.SCOR_DROP_TRIGGER TR_SCOR_SA_REQUEST_UPDATE;
GO
dbo.SCOR_DROP_TRIGGER TR_SCOR_SA_REQUEST_DELETE;
GO


dbo.SCOR_DROP_PROCEDURE SCOR_DROP_FUNCTION;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_DROP_VIEW;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_DROP_TRIGGER;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_DROP_TABLE;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_CLEANUP_SCOR_COMMON_BINARY_INFO
GO
dbo.SCOR_DROP_PROCEDURE SCOR_DROP_PARTITION_SCHEME;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_DROP_PARTITION_FUNCTION;
GO
dbo.SCOR_DROP_PROCEDURE SCOR_DROP_NOT_NAMED_CONSTRAINT;
GO


if exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_PROCEDURE]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SCOR_DROP_PROCEDURE];
GO

/*The five procedures(SCOR_DROP_FUNCTION,SCOR_DROP_VIEW,SCOR_DROP_TABLE,SCOR_DROP_TRIGGER,SCOR_DROP_PROCEDURE)  must be the last four procedures to
 be dropped.Add all statements above these four procedures.*/


